<!------------------------------------------------------------------------------
# Author(s):
#    Simone Alioli, Christian Bauer, Frank Tackmann
#
# Copyright:
#    Copyright (C) 2017, 2018 Geneva Collaboration
#
#    This file is part of the Geneva MC framework. Geneva is distributed under
#    the terms of the GNU General Public License version 3 (GPLv3), see the
#    COPYING file that comes with this distribution for details.
#    Please respect the academic usage guidelines in the GUIDELINES file.
#
# Description:
#    Main README and start page of the documentation.
#
#    All [links] in the documentation files are given at the end of each file.
#    A user-friendly browsable version of this documentation is available at
#
#    https://stash.desy.de/projects/GENEVA/repos/geneva-public/browse/README.md
#------------------------------------------------------------------------------>
![GENEVA]
##### Main | [Installation] | [User Guide] | [Tutorial] | [Index] #####
--------------------------------------------------------------------------------

Geneva Monte Carlo
===================

Geneva is a Monte-Carlo event generator based on resummed NNLO+NNLL'
calculations.  It produces LHEF events, which can be showered and hadronized
with a parton-shower generator (currently Pythia8) to produce fully exclusive
HepMC events.

The currently available processes at NNLO+NNLL' are:

 * p p -> Z/gamma -> e+ e-
 * p p -> Z/gamma -> mu+ mu-

The current version is 1.0-RC3.

_This is a release candidate, and as such can still contain bugs and missing
features. We kindly ask that you report back to us results and problems obtained
with this preliminary version prior to their usage in any publication._


Authors
--------

_Main developers:_

Simone Alioli,
Christian Bauer,
Frank Tackmann

_People who have contributed at various stages:_

Calvin Berggren,
Sam Guns,
Andrew Hornig,
Chris Vermilion,
Jonathan Walsh,
Saba Zuberi

Please share any issues you might find with us by sending an email to
<geneva@lbl.gov>.


Documentation
--------------

Please see

 * the [Installation] instructions for how to obtain and build the code.
 * the [User Guide] for how to run the code.
 * the [Tutorial] for a step-by-step example how to perform a complete run.

If you have questions or require additional help, feel free to contact us via
email to <geneva@lbl.gov>.


References
-----------

Please respect the [academic usage guidelines](GUIDELINES.md).

If you use this program or its results in academic work, please cite the
following papers:

 * S. Alioli et al., _Combining Higher-Order Resummation with Multiple NLO Calculations and Parton Showers in Geneva_,
   JHEP 1309 (2013) 120, [arXiv:1211.7049]
   [(link to Inspire)](http://inspirehep.net/record/1204791?ln=en)

 * S. Alioli et al., _Matching Fully Differential NNLO Calculations and Parton Showers_,
   JHEP 1406 (2014) 089, [arXiv:1311.0286]
   [(link to Inspire)](http://inspirehep.net/record/1263191?ln=en)

 * S. Alioli et al., _Drell-Yan production at NNLL'+NNLO matched to parton showers_,
   Phys.Rev. D92 (2015) no.9, 094020, [arXiv:1508.01475]
   [(link to Inspire)](http://inspirehep.net/record/1386859?ln=en)

 * S. Alioli et al., _Underlying event sensitive observables in Drell-Yan production using Geneva_,
   Eur. Phys. J. C76 (2016) no.11, 614, [arXiv:1605.07192]
   [(link to Inspire)](https://inspirehep.net/record/1465508?ln=en)


### License ###

Copyright &copy; 2017, 2018 Geneva Collaboration, CERN, DESY, LBNL, UNIMB

The Geneva MC framework is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program in the COPYING file. If not, see <http://www.gnu.org/licenses/>.


[links]: #----------------------------------------------------------------------

[Installation]: doc/Installation.md
[User Guide]:   doc/UserGuide.md
[Tutorial]:     doc/tutorial/Tutorial.md
[Index]:        doc/Index.md
[GENEVA]:       doc/geneva.jpg

[arXiv:1211.7049]:  http://arxiv.org/abs/arXiv:1211.7049
[arXiv:1311.0286]:  http://arxiv.org/abs/arXiv:1311.0286
[arXiv:1508.01475]: http://arxiv.org/abs/arXiv:1508.01475
[arXiv:1605.07192]: http://arxiv.org/abs/arXiv:1605.07192
