#-------------------------------------------------------------------------------
# CMake module to find the OpenLoops library and headers.
#
# Copyright (C) 2017  Frank Tackmann
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at http://www.apache.org/licenses/LICENSE-2.0.
#-------------------------------------------------------------------------------
#
# The following variables can be set by the user:
#  openloops_ROOT            : The root directory of the OpenLoops installation (cache)
#  openloops_SEARCH_PATH     : Additional prefix paths to search (cache)
#  openloops_NO_DEFAULT_PATH : If set, skips searching the CMake default paths
#
# The following imported targets are defined:
#  openloops::openloops : The openloops library
#
# The following variables are set:
#  openloops_FOUND        : TRUE if library, headers, and all required components are found
#  openloops_VERSION      : The found version
#
#  openloops_LIBRARY      : Cache variable storing the found library
#
# There are two search modes, depending on whether openloops_ROOT is set or not.
#
# If openloops_ROOT is specified, the library is searched in
# openloops_ROOT/lib. No other paths are searched.
# Whenever openloops_ROOT changes, previous search results are discarded
# (including when openloops_ROOT is unset). This allows the user to explicitly
# force using a specific installation.
#
# Otherwise, the search proceeds as follows:
# 1. No search is performed if openloops_LIBRARY is
#    present from a previous search (or manually set by the user, but see below)
# 2. The default system paths according to CMake are searched (see the CMake
#    documentation) unless openloops_NO_DEFAULT_PATH is set.
# 3. The additional paths in openloops_SEARCH_PATH are searched with
#    suffix 'lib'
#
# Once the library is found, its location is stored and not searched again.
# Since openloops doesn't provide headers, there is currently no way to figure
# out the version.
#
# To completely bypass any searching or override the found location, the user
# can directly set the openloops_LIBRARY cache variable.
# This should only be used as a last resort in case of nonstandard
# or conflicting installations where specifying openloops_SEARCH_PATH or
# openloops_ROOT is insufficient. In this case it is up to the user to ensure
# that the library exists.
#-------------------------------------------------------------------------------

include (FindPackageHelper)

find_package_helper (openloops
   NO_HEADER
   LIBRARY openloops
   LIB_SUFFIXES lib proclib
)

if (TARGET openloops::openloops)
   get_filename_component (openloops_INSTALL_PATH "${openloops_LIBRARY}" DIRECTORY)
   get_filename_component (openloops_INSTALL_PATH "${openloops_INSTALL_PATH}/.." REALPATH)
endif()
