#-------------------------------------------------------------------------------
# CMake module to find the Pythia8 library and headers.
#
# Copyright (C) 2017  Frank Tackmann
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at http://www.apache.org/licenses/LICENSE-2.0.
#-------------------------------------------------------------------------------
#
# The following variables can be set by the user:
#  pythia8_ROOT            : The root directory of the Pythia8 installation (cache)
#  pythia8_SEARCH_PATH     : Additional prefix paths to search (cache)
#  pythia8_NO_DEFAULT_PATH : If set, skips searching the CMake default paths
#
# The following imported targets are defined:
#  pythia8::pythia8 : The pythia8 library
#
# The following variables are set:
#  pythia8_FOUND        : TRUE if library and headers are found
#  pythia8_VERSION      : The found version
#
#  pythia8_LIBRARY      : Cache variable storing the found library
#  pythia8_INCLUDE_DIR  : Cache variable storing the found include directory
#  pythia8_DATA_DIR     : Cache variable storing the found data directory
#
# There are two search modes, depending on whether pythia8_ROOT is set or not.
#
# If pythia8_ROOT is specified, the library and headers are searched in
# pythia8_ROOT/lib and pythia8_ROOT/include. No other paths are searched.
# Whenever pythia8_ROOT changes, previous search results are discarded
# (including when pythia8_ROOT is unset). This allows the user to explicitly
# force using a specific installation.
#
# Otherwise, the search proceeds as follows:
# 1. No search is performed if pythia8_LIBRARY or pythia8_INCLUDE_DIR are
#    present from a previous search (or manually set by the user, but see below)
# 2. The default system paths according to CMake are searched (see the CMake
#    documentation) unless pythia8_NO_DEFAULT_PATH is set.
# 3. The additional paths in pythia8_SEARCH_PATH are searched with respective
#    suffixes 'lib' and 'include'
#
# Once both library and headers with an acceptable version are found, their
# location is stored and not searched again.
#
# In addition, the pythia8 data files are searched for in the locations
# share/Pythia8/xmldoc and Pythia8/xmldoc relative to either pythia8_ROOT or the
# search paths. They are treated like optional components and not as required.
#
# To completely bypass any searching or override the found location, the user
# can directly set the pythia8_LIBRARY and pythia8_INCLUDE_DIR cache
# variables. This should only be used as a last resort in case of nonstandard
# or conflicting installations where specifying pythia8_SEARCH_PATH or
# pythia8_ROOT is insufficient. In this case the headers are still checked for
# a compatible version but otherwise it is up to the user to ensure that the
# library and headers exist and are consistent with each other.
#-------------------------------------------------------------------------------

include (FindPackageHelper)

find_package_helper (pythia8
   LIBRARY pythia8
   HEADERS "Pythia8/Pythia.h"
   DATA_FILES "ParticleData.xml" SHARE_SUFFIXES "share/Pythia8/xmldoc" "Pythia8/xmldoc"
   VERSION_REGEX ".*#define PYTHIA_VERSION ([0-9\\.]+)$"
)
