#-------------------------------------------------------------------------------
# CMake module to find the YODA library and headers.
#
# Copyright (C) 2018  Frank Tackmann, Simone Alioli
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at http://www.apache.org/licenses/LICENSE-2.0.
#-------------------------------------------------------------------------------
#
# The following variables can be set by the user:
#  yoda_ROOT            : The root directory of the YODA installation (cache)
#  yoda_SEARCH_PATH     : Additional prefix paths to search (cache)
#  yoda_NO_DEFAULT_PATH : If set, skips searching the CMake default paths
#
# The following imported targets are defined:
#  yoda::yoda: The yoda library
#
# The following variables are set:
#  yoda_FOUND        : TRUE if library and headers are found
#  yoda_VERSION      : The found version
#
#  yoda_LIBRARY      : Cache variable storing the found library
#  yoda_INCLUDE_DIR  : Cache variable storing the found include directory
#
# There are two search modes, depending on whether yoda_ROOT is set or not.
#
# If yoda_ROOT is specified, the library and headers are searched in
# yoda_ROOT/lib and yoda_ROOT/include. No other paths are searched.
# Whenever yoda_ROOT changes, previous search results are discarded
# (including when yoda_ROOT is unset). This allows the user to explicitly
# force using a specific installation.
#
# Otherwise, the search proceeds as follows:
# 1. No search is performed if yoda_LIBRARY or yoda_INCLUDE_DIR are
#    present from a previous search (or manually set by the user, but see below)
# 2. The default system paths according to CMake are searched (see the CMake
#    documentation) unless yoda_NO_DEFAULT_PATH is set.
# 3. The additional paths in yoda_SEARCH_PATH are searched with respective
#    suffixes 'lib' and 'include'
#
# Once both library and headers with an acceptable version are found, their
# location is stored and not searched again.
#
# To completely bypass any searching or override the found location, the user
# can directly set the yoda_LIBRARY and yoda_INCLUDE_DIR cache
# variables. This should only be used as a last resort in case of nonstandard
# or conflicting installations where specifying yoda_SEARCH_PATH or
# yoda_ROOT is insufficient. In this case the headers are still checked for
# a compatible version but otherwise it is up to the user to ensure that the
# library and headers exist and are consistent with each other.
#-------------------------------------------------------------------------------

include (FindPackageHelper)

find_package_helper (yoda
   LIBRARY YODA
   HEADERS "YODA/YODA.h"
   VERSION_FILES "YODA/Config/YodaConfig.h"
   VERSION_REGEX ".*#define YODA_VERSION \"([0-9\\.]+)\"$"
)
