#-------------------------------------------------------------------------------
# CMake module to find the zlib library and headers.
#
# Copyright (C) 2017  Frank Tackmann
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at http://www.apache.org/licenses/LICENSE-2.0.
#-------------------------------------------------------------------------------
#
# The following variables can be set by the user:
#  zlib_ROOT            : The root directory of the zlib installation (cache)
#  zlib_SEARCH_PATH     : Additional prefix paths to search (cache)
#  zlib_NO_DEFAULT_PATH : If set, skips searching the CMake default paths
#
# The following imported targets are defined:
#  zlib::zlib : The zlib library
#
# The following variables are set:
#  zlib_FOUND        : TRUE if library, headers, and all required components are found
#  zlib_VERSION      : The found version
#
#  zlib_LIBRARY      : Cache variable storing the found library
#  zlib_INCLUDE_DIR  : Cache variable storing the found include directory
#
# There are two search modes, depending on whether zlib_ROOT is set or not.
#
# If zlib_ROOT is specified, the library and headers are searched in
# zlib_ROOT/lib and zlib_ROOT/include. No other paths are searched.
# Whenever zlib_ROOT changes, previous search results are discarded
# (including when zlib_ROOT is unset). This allows the user to explicitly
# force using a specific installation.
#
# Otherwise, the search proceeds as follows:
# 1. No search is performed if zlib_LIBRARY or zlib_INCLUDE_DIR are
#    present from a previous search (or manually set by the user, but see below)
# 2. The default system paths according to CMake are searched (see the CMake
#    documentation) unless zlib_NO_DEFAULT_PATH is set.
# 3. The additional paths in zlib_SEARCH_PATH are searched with respective
#    suffixes 'lib' and 'include'
#
# Once both library and headers with an acceptable version are found, their
# location is stored and not searched again.
#
# To completely bypass any searching or override the found location, the user
# can directly set the zlib_LIBRARY and zlib_INCLUDE_DIR cache
# variables. This should only be used as a last resort in case of nonstandard
# or conflicting installations where specifying zlib_SEARCH_PATH or
# zlib_ROOT is insufficient. In this case the headers are still checked for
# a compatible version but otherwise it is up to the user to ensure that the
# library and headers exist and are consistent with each other.
#-------------------------------------------------------------------------------

include (FindPackageHelper)

find_package_helper (zlib
   LIBRARY z zlib zdll zlib1
   HEADERS "zlib.h"
   VERSION_REGEX ".*#define ZLIB_VERSION \"([0-9\\.]+)\"$"
   LANGUAGES "C"
)
