#-------------------------------------------------------------------------------
# Author(s):
#    Frank Tackmann
#
# Copyright:
#    Copyright (C) 2015 Frank Tackmann
#
#    This file is part of the Geneva MC framework. Geneva is distributed under
#    the terms of the GNU General Public License version 3 (GPLv3), see the
#    COPYING file that comes with this distribution for details.
#    Please respect the academic usage guidelines in the GUIDELINES file.
#
# Description:
#    cmake script for configuration at build time
#-------------------------------------------------------------------------------

# Add a custom target to call ourselves at build-time.
# Having targets depend on this target enables the build-time configuration.
if (DEFINED PROJECT_NAME)
   set (_config_flags
      -DPROJECT_SOURCE_DIR=${PROJECT_SOURCE_DIR}
      -DCMAKE_BINARY_DIR=${CMAKE_BINARY_DIR}
      -DGIT_EXECUTABLE=${GIT_EXECUTABLE}
   )
   add_custom_target (geneva-configure-at-build ALL
      ${CMAKE_COMMAND} ${_config_flags} -P ${CMAKE_CURRENT_LIST_FILE}
      COMMENT "Performing build-time configuration."
      VERBATIM
   )
   unset (_config_flags)
endif ()

if (NOT DEFINED geneva_VERSION)
   include (${PROJECT_SOURCE_DIR}/geneva-config-version.cmake)
endif ()

if (GIT_CHANGES)
   string (REPLACE "\n" "\\n" GIT_CHANGES_STRING ${GIT_CHANGES})
endif ()

configure_file (
  ${PROJECT_SOURCE_DIR}/include/version.hpp.in
  ${CMAKE_BINARY_DIR}/include/Geneva/version.hpp
  @ONLY
)
