<!------------------------------------------------------------------------------
# Author(s):
#    Simone Alioli, Christian Bauer, Frank Tackmann
#
# Copyright:
#    Copyright (C) 2017, 2018 Geneva Collaboration
#
#    This file is part of the Geneva MC framework. Geneva is distributed under
#    the terms of the GNU General Public License version 3 (GPLv3), see the
#    COPYING file that comes with this distribution for details.
#    Please respect the academic usage guidelines in the GUIDELINES file.
#
# Description:
#    Installation instructions
#------------------------------------------------------------------------------>
![GENEVA]
##### [Main] | Installation | [User Guide] | [Tutorial] | [Index] #####
--------------------------------------------------------------------------------

Installation
=============

Download the code
------------------

The latest version can be obtained by cloning from the DESY or LBL git mirrors

    $ git clone https://stash.desy.de/scm/geneva/geneva-public.git

or

    $ git clone http://geneva.physics.lbl.gov/git/geneva-public.git

It can also be downloaded as [.tar.gz] or [.zip] file or directly from the
[repository].


Building
---------

### Requirements ###

Geneva uses [CMake] as its build system. The minimum required CMake version is
3.5, which is available as standard package on any recent Linux distribution.

Geneva is written in C++ and requires at minimum a C++11 compiler. [Python]
version 2.7 is required for using the Python interface (see below).

The installation has been tested on the following systems:

 * Debian Stretch with GCC 6.3
 * Debian Jessie with GCC 4.9.2
 * Ubuntu 16.04 with GCC 5.4
 * OpenSuse 42.3 with GCC 4.8.5
 * OpenSuse Leap 15 with gcc 7.3.1
 * CERN CentOS 7.3 with GCC 5.2
 * Mac OSX 10.13 (Darwin 17.5) with AppleClang 9.1.0

Geneva requires the following external libraries:

 * [GSL] minimum version 1.13
 * [zlib] (required for using zipped event files)
 * [LHAPDF] minimum version 6.2
 * [Pythia8] minimum version 8.230 (required for showering)
 * [HepMC] minimum version 2.06.08 (required for HepMC output)
 * [OpenLoops] minimum version 3.1.3
 * [Rivet] minimum version 2.5 (required to analyze HepMC output with Rivet)

GSL and zlib have to be provided by the system. On Ubuntu they are provided by
the `libgsl2` and `libgsl-dev`, `zlib1g` and `zlib1g-dev` packages. The other
libraries can be automatically installed by Geneva if desired (see below).


#### Python ####

Python 2.7 is required to take advantage of the Python interface to steer the
running. It uses a variety of modules from the Python standard library.

In addition, the `numpy` module is required, and to use MPI running, the
`mpi4py` package is needed. To produce diagnostic plots (as explained in
[Setup Files]) the `matplotlib` module is needed. These modules are available on
any recent Linux distribution. A Python distribution that contains all the
required packages (and many more) is [Anaconda].

Note that at build time, CMake only checks for the availability of the Python
interpreter itself. If a required Python module is missing, a corresponding
error message is displayed at runtime.


#### LHAPDF ####

PDFs are provided by LHAPDF. In addition to the main desired PDF set, the
CT10nnlo set is required internally. (Due to its positivity it is used as
fallback choice in the evaluation of splitting probabilities when the chosen PDF
set is not positive-definite.) If either set is not available, an error is
raised at runtime.


#### OpenLoops ####

All matrix elements are taken from OpenLoops. Currently, the process packages
`ppll`, `ppllj`, and `pplljj` are required and need to be installed through the
OpenLoops machinery. CMake checks if they are present and comments if it cannot
locate them.

OpenLoops loads its process libraries dynamically at runtime. Geneva
automatically sets the `install_path` of OpenLoops at runtime to the value of
the directory where OpenLoops was found by CMake. If the `OpenLoopsPath`
environment variable is nonempty it takes precedence and is used instead. If at
runtime OpenLoops cannot find its process libraries in `install_path/proclib`,
the program will abort with an error.


### Configuring with CMake ###

#### Overview ####

CMake requires out-of-source builds, keeping the source tree clean.

    $ cd geneva-public
    geneva-public$ mkdir build && cd build
    build$ cmake ..

The argument to `cmake` here specifies the path to the geneva source tree. So
more generally, if the build directoy is somewhere else, do

    build/some/where$ cmake path/to/geneva

To start over, simply create a new build directory. Multiple separate build
directories are also possible.

CMake maintains a persistent cache with the current configuration, which can be
updated. To see and edit the configuration from a terminal do

    build$ ccmake ..

CMake variables can either be edited inside ccmake or directly specified from
command line with the `-D` option as

    build$ cmake -D<variable>=<value> ..

Some useful CMake variables with their _default_ (all possible) values are:

 * `CMAKE_BUILD_TYPE`:  _Release_ (Release, RelWithDebInfo, Debug, MinSizeRel)
 * `BUILD_SHARED_LIBS`: _on_ (on, off)


#### Finding external dependencies ####

On its first run CMake searches the system for all dependencies in several
standard locations. If some dependencies are not found, it will return an error
or warning. Please look carefully at the output.

To tell CMake whether to use a particular library at all, and if so, where it
is located, the following CMake variables can be used:

 * `CMAKE_PREFIX_PATH`: Additional paths to be used as default paths
 * `geneva_enable_<library>`: Enable (on) or disable (off) using the library
 * `<library>_SEARCH_PATH`: Additional paths to search (after default paths)
 * `<library>_ROOT`: Force using a single fixed location for the library

The paths here must point to the root (prefix) directory of an installation.
Note that CMake by default does not search for something again that it has
previously found. The exception is the `<library>_ROOT` variable, which when
changed will force CMake to switch to the specified location. (A detailed
documentation for each library can be found in the corresponding
`cmake/Modules/Find<library>.cmake` module.) For example, to specify fixed
locations for the above external libraries do

    build$ cmake -Dgsl_ROOT=path/to/gsl -Dlhapdf_ROOT=path/to/lhapdf -Dpythia8_ROOT=path/to/pythia8 -Dhepmc_ROOT=path/to/hepmc -Dopenloops_ROOT=path/to/openloops ..

The above does not apply to the C++ compiler and Python, as these are natively
searched for by CMake. See the extensive [CMake] documentation for details.

If an external library is disabled (or enabled but not found), Geneva will be
built with the corresponding features turned off.


### Installing missing libraries ###

In case an external library is missing, Geneva's build system is able to
automatically download, build, and install some of the external libraries. The
following make targets install the respective library:

    build$ make lhapdf
    build$ make hepmc
    build$ make pythia8
    build$ make openloops

The libraries are build and installed in the directory `external`.  This
location can be customized using the `geneva_external_prefix` CMake variable.
Upon completion, the corresponding `<library>_ROOT` will automatically be set
to this location. (_Note: This feature should **not** be used to install the
libraries in a system location._)

_Please note that this feature is provided solely for the user's convenience._
It might fail if your system is too old or nonstandard. Please check the final
output and, in case of failures, install the libraries yourself following the
respective build instructions for your system and specify their location to
CMake as described above.

The `make lhapdf` command also downloads a minimal number of PDF grids
(corresponding to the selected beam functions, see below). This can also be
triggered by hand using `make lhapdf-install-data`.


#### OpenLoops ####

The `make openloops` target installs OpenLoops together with the required
process libraries (see above).

Installing OpenLoops requires Fortran and Python. OpenLoops has its own way of
finding Python, independently from what is found by CMake. This could lead to
problems on systems with multiple Python installations, in particular if the one
found by OpenLoops lacks some needed modules.

To avoid this issue, make sure to have a consistent Python installation and/or
install OpenLoops by hand pointing it to the desired Python installation.


#### Rivet ####

Rivet is by default turned off, but can be turned on by doing

    build$ cmake -Dgeneva_enable_rivet=on ..

which makes the analyze-rivet stage available.

Rivet requires YODA, HepMC, and FastJet, which are automatically searched for by
CMake when it searches for Rivet. The `make rivet` target can be used to install
Rivet in the `external` directory. For this purpose, a `make yoda` target is
also provided, which is called by `make rivet` if YODA was not found. If HepMC
or FastJet are not found on the system, they must be explicitly enabled to
provide corresponding `make hepmc` or `make fastjet` targets for `make rivet`
to call.


### Building the main code ###

Once all external code has been found, the main Geneva code is built using

    build$ make

The libraries and binaries are placed into `build/lib` and `build/bin`,
respectively.


### Data files ###

Geneva requires some data files at runtime. Their location can be configured
at build time with the `geneva_DATA_DIR` CMake variable. By default, it points
to the `share/Geneva` directory of the source tree, where the files are located.

If at runtime the `GENEVA_DATA_DIR` environment variable is nonempty, it takes
precedence and is used instead. This allows to relocate the data files if
desired.


#### Beam function data files ####

For running the resummed calculation, Geneva requires beam function grids that
need to correspond to the choice of PDF used. The required data files must be
installed via

    build$ make beamfunc-install-data

This downloads the files into the `geneva_DATA_DIR/beamfunc` directory. At
runtime they are always looked for in the `beamfunc` subdirectory of the runtime
data directory (either `geneva_DATA_DIR` or if nonempty `GENEVA_DATA_DIR`).

If `geneva_DATA_DIR` points to the source tree, `make beamfunc-install-data`
should be done before doing a `make install` (see below), such that the
downloaded beam function files are copied to the install location.

Currently beam-function data files (_for the central members only_) are provided
for the following PDF sets:

 * `CT10nnlo`, `CT14nnlo`
 * `MMHT2014nnlo68cl`
 * `NNPDF31_nnlo_as_0118`, `NNPDF30_nnlo_as_0118`
 * `PDF4LHC15_nnlo_100`, `PDF4LHC15_nnlo_30`, `PDF4LHC15_nnlo_mc`

which can be specified with the `beamfunc_PDF_SETS` CMake variable. Additional
PDF sets will be provided in the future and upon request.

The corresponding LHAPDF grid files must be available to LHAPDF as well. Lacking
them, an error is raised at runtime (see above).


### Installing ###

_Note: The installation step is optional and is primarily provided to provide
relocatability if needed. For single uses, it is easiest to run from the build
directory, which is what is assumed in the [Tutorial] and [User Guide]._

To install Geneva, do

    build$ make install

This installs the libraries, binaries, public headers, and data into the
`<prefix>/lib`, `<prefix>/bin`, `<prefix>/include/Geneva`, and
`<prefix>/share/Geneva` directories, respectively. (Currently, the directories
cannot be specified individually.)

Some CMake variables that steer the installation process are:

 * `CMAKE_INSTALL_PREFIX`: The installation `<prefix>` (default is `/usr/local`)
 * `CMAKE_INSTALL_RPATH`: The runtime library path (default is empty).

There are various choices for `CMAKE_INSTALL_RPATH`. If empty, the installed
shared libraries and binaries contain no runtime library paths (RPATH or
RUNPATH). This provides the maximum flexibility and makes the installation fully
relocatable. In this case, the `LD_LIBRARY_PATH` environment variable must be
set appropriately to find any libraries (both Geneva and external libraries)
that are not installed in standard locations. Similarly, to use the Python
interface, the `PYTHONPATH` must be set appropriately. The data location can
be specified at runtime via `GENEVA_DATA_DIR` (see above).

To install Geneva into a fixed (non-system) location, set `CMAKE_INSTALL_RPATH`
to `CMAKE_INSTALL_PREFIX/lib`. In that way, the Geneva libraries are always
found by each other and the binaries. In addition, you could add the
`geneva_external_prefix/lib` directory, such that any external libraries
installed there are automatically found.

If you have trouble running from the install location, please run from the
build directory.


#### Uninstalling ####

For safety reasons, CMake does not provide a `make uninstall` target. A list of
all installed files is provided in the `build/install_manifest.txt` file.
Normally, it should be sufficient to do the following

    $ rm <prefix>/bin/geneva*
    $ rm <prefix>/lib/libGeneva*
    $ rm -rf <prefix>/lib/python2.7/site-packages/genevapylib
    $ rm -rf <prefix>/include/Geneva
    $ rm -rf <prefix>/share/Geneva


Installation on specific systems
---------------------------------

Here we provide examples of how to build Geneva on a few specific clusters.
Please adapt these to your needs.


### CERN LXPLUS ###

Here we give an example of build tools and external libraries that has been
validated to work on lxplus.cern.ch.

An appropriate version of all required build tools and most external packages is
available on AFS. So in this example, Geneva is built by pointing CMake to
existing location for most packages.

    build$ source /afs/cern.ch/sw/lcg/contrib/gcc/4.8/x86_64-slc6-gcc48-opt/setup.sh
    build$ alias cmake="/afs/cern.ch/sw/lcg/external/CMake/3.5.2/Linux-x86_64/bin/cmake"
    build$ cmake -DCMAKE_CXX_COMPILER=$CXX -Dhepmc_ROOT=/afs/cern.ch/sw/lcg/external/HepMC/2.06.08/x86_64-slc6-gcc48-opt -Dpythia8_ROOT=/afs/cern.ch/sw/lcg/external/MCGenerators_lcgcmt67c/pythia8/235/x86_64-slc6-gcc48-opt -Dopenloops_ROOT=/afs/cern.ch/sw/lcg/external/MCGenerators_lcgcmt67c/openloops/1.3.1/x86_64-slc6-gcc48-opt -Dlhapdf_ROOT=/afs/cern.ch/sw/lcg/external/MCGenerators_lcgcmt67c/lhapdf/6.2.0/x86_64-slc6-gcc48-opt -Dgsl_ROOT=/afs/cern.ch/sw/lcg/external/GSL/2.2.1/x86_64-slc6-gcc48-opt
    build$ export LHAPDF_DATA_PATH=/afs/cern.ch/sw/lcg/external/lhapdfsets/current/
    build$ make beamfunc-install-data
    build$ make


### NERSC Edison ###

An appropriate version of all required build tools is available via modules on
NERSC systems. The external packages need to be installed separately. In this
example, they are built and installed via CMake in `external`.

    build$ module unload PrgEnv-intel
    build$ module unload PrgEnv-gnu
    build$ module load gsl
    build$ module load python/2.7
    build$ module load cmake
    build$ module load mpi4py
    build$ module load PrgEnv-gnu #(necessary to reload here because of a bug in module load cmake)
    build$ export CXX=/opt/gcc/7.1.0/bin/g++
    build$ export CC=/opt/gcc/7.1.0/bin/gcc
    build$ export FF=/opt/gcc/7.1.0/bin/gfortran
    build$ export F77=$FF
    build$ export F90=$FF
    build$ cmake -Dgsl_ROOT=$GSL_DIR -DCMAKE_CXX_COMPILER=$CXX ..
    build$ make geneva-external
    build$ make beamfunc-install-data
    build$ make


Known issues
-------------

### MacOSX 10.9 or higher ###

Starting with Mac OSX 10.9, libc++ is chosen as the default C++ standard library,
whereas libstdc++ was used as default on 10.8 and earlier versions.
When the Python version on the system is built against libstdc++ and the default
C++ library used by the build toolchain is libc++, or vice-versa, link errors
can be reported. We suggest the users to fix their systems by using the same
standard C++ library for all binaries. In case this cannot be easily done, we have
added the possibility to force the Python C++ extension to be built against the
default C++ library used by the build toolchain. This can be achieved by either
explicitly setting  the `MACOSX_DEPLOYMENT_TARGET` environment variable
to the version of the SDK, or by informing CMake of it via e.g.

    build$ cmake -DCMAKE_OSX_DEPLOYMENT_TARGET=10.9.0 ..

### MacOSX 10.11 or higher ###

Since several of the external packages don’t set the correct `rpath`, you need
to tell the system the location of some of these packages using the environment
variable `DYLD_LIBRARY_PATH`. Note that if more than one version of an external
package exists on your system, the ordering of the various paths might affect
which version will be used at runtime.

Starting with Mac OSX 10.11 (El Capitain) or higher, the built-in System
Integrity Protection removes the `DYLD_LIBRARY_PATH` variable from the Python
environment used to run Geneva. To get around this issue, set the environment
variable `GENEVA_EXTERNAL_LIBRARY_PATH` to the desired value for
`DYLD_LIBRARY_PATH`. This variable is then used to set `DYLD_LIBRARY_PATH` in
the Python environment.


[links]: #----------------------------------------------------------------------

[Main]:               ../README.md
[User Guide]:         UserGuide.md
[Tutorial]:           tutorial/Tutorial.md
[Setup Files]:        SetupFiles.md
[Index]:              Index.md
[GENEVA]:             geneva.jpg

[.tar.gz]:    https://stash.desy.de/rest/api/latest/projects/GENEVA/repos/geneva-public/archive?format=tar.gz  (download as .tar.gz)
[.zip]:       https://stash.desy.de/rest/api/latest/projects/GENEVA/repos/geneva-public/archive?format=zip     (download as .zip)
[repository]: https://stash.desy.de/projects/GENEVA/repos/geneva-public

[CMake]:     https://cmake.org/                           (CMake homepage)
[Anaconda]:  https://www.continuum.io/downloads           (Anaconda download page)
[GSL]:       http://www.gnu.org/software/gsl/             (GSL homepage)
[Boost]:     http://www.boost.org                         (Boost homepage)
[Python]:    http://www.python.org                        (Python homepage)
[zlib]:      http://www.zlib.net/                         (zlib homepage)
[LHAPDF]:    https://lhapdf.hepforge.org                  (LHAPDF homepage)
[Pythia8]:   http://home.thep.lu.se/~torbjorn/Pythia.html (Pythia8 homepage)
[HepMC]:     http://hepmc.web.cern.ch/hepmc/              (HepMC homepage)
[OpenLoops]: https://openloops.hepforge.org               (OpenLoops homepage)
[Rivet]:     https://rivet.hepforge.org/                  (Rivet homepage)
