<!------------------------------------------------------------------------------
# Author(s):
#    Simone Alioli, Christian Bauer, Frank Tackmann
#
# Copyright:
#    Copyright (C) 2017, 2018 Geneva Collaboration
#
#    This file is part of the Geneva MC framework. Geneva is distributed under
#    the terms of the GNU General Public License version 3 (GPLv3), see the
#    COPYING file that comes with this distribution for details.
#    Please respect the academic usage guidelines in the GUIDELINES file.
#
# Description:
#    NNLO cross section
#------------------------------------------------------------------------------>
![GENEVA]
##### [Main] | [Installation] | [User Guide] | [Tutorial] | [Index] #####
--------------------------------------------------------------------------------

NNLO Cross Section
===================

To perform the reweighting of the 0-jet events to correct for the neglected
nonsingular contributions below the resolution cutoff Tau0cut, the full (target)
NNLO cross section below Tau0cut must be known.

Internally, Geneva takes the hard scale in the resummation region to be the
dilepton invariant mass Q = M_ll. Therefore, the target NNLO cross section is
needed for the central scale choice mu = Q, as well as for the overall up and
down scale variations, mu = 2Q and mu = Q/2.


Target cross section for selected options
------------------------------------------

| Energy | PDF                | alphas(mZ)| Generation Cuts [GeV] | sigma [pb], mu = (Q, 2Q, Q/2) |
|--------|--------------------|-----------|-----------------------|-------------------------------|
| 7 TeV  | PDF4LHC15_nnlo_100 |  0.1180   | 60 < M_ll < 120       | (  32.64,  47.50,  17.00 )    |
| 7 TeV  | PDF4LHC15_nnlo_100 |  0.1135   | 60 < M_ll < 120       | (  61.31,  76.07,  45.31 )    |
| 8 TeV  | PDF4LHC15_nnlo_100 |  0.1180   | 60 < M_ll < 120       | (  34.63,  49.71,  17.07 )    |
| 8 TeV  | PDF4LHC15_nnlo_100 |  0.1135   | 60 < M_ll < 120       | (  66.74,  83.52,  50.29 )    |
| 13 TeV | PDF4LHC15_nnlo_100 |  0.1180   | 50 < M_ll < 150       | (  35.96,  55.97,  14.27 )    |
| 13 TeV | PDF4LHC15_nnlo_100 |  0.1135   | 50 < M_ll < 150       | (  89.87, 111.84,  65.84 )    |

The target cross section depends of course on various parameters, like the
collider energy, PDF set, alphas(mZ), dilepon cuts, etc. The relevant results
for a selected set of parameters are given in the table above. The three values
in the last column are passed to the reweighting stage using the argument
`--sigma-below <central> <up> <down>` (see the [User Guide]).

The target cross section of course also depends on the used value of Tau0cut. At
present, it is fixed to Tau0cut = 1 GeV, and all results above correspond to
that value.


Calculating target cross sections for other options
----------------------------------------------------

To obtain the required numbers for combinations of generation parameters not
listed in the above table, first obtain the total inclusive NNLO cross section
from an independent NNLO calculation for the desired parameters for the three
scales mu = muR = muF = Q, mu = Q/2, and mu = 2Q.

Next, perform a separate Geneva run with the desired parameters and setting
the fixed-order scale in the calculation options to a dynamic invariant mass
scale:

```yaml
calculation:
   SCETppV012:
      scale_settings:
         fixed_order:
            dynamic: InvariantMass
```

The so-generated `<file>.lhe[.gz]` files (gzipped when CMake's
geneva_enable_zlib is ON and zlib is found) are now combined to calculate the
inclusive 1-jet cross section for Tau0 > Tau0cut by calling

    build$ bin/geneva-lhef-xsec <files...>.lhe[.gz] --multiplicity 4 --outfile xsec_info.dat

This produces a file `xsec_info.dat`, which contains the 1-jet inclusive cross
sections for the central, up, and down scale choices in the variables
`sigmaAbove`, `sigmaAboveUp`, and `sigmaAboveDown`, respectively.

Subtracting these inclusive 1-jet cross sections from the respective total NNLO
cross sections obtained before gives the required NNLO target cross sections for
Tau0 < Tau0cut.


[links]: #----------------------------------------------------------------------

[Main]:               ../README.md
[Installation]:       Installation.md
[User Guide]:         UserGuide.md
[Tutorial]:           tutorial/Tutorial.md
[Index]:              Index.md
[GENEVA]:             geneva.jpg
