<!------------------------------------------------------------------------------
# Author(s):
#    Simone Alioli, Christian Bauer, Frank Tackmann
#
# Copyright:
#    Copyright (C) 2017, 2018 Geneva Collaboration
#
#    This file is part of the Geneva MC framework. Geneva is distributed under
#    the terms of the GNU General Public License version 3 (GPLv3), see the
#    COPYING file that comes with this distribution for details.
#    Please respect the academic usage guidelines in the GUIDELINES file.
#
# Description:
#    Documentation of generated setup files
#------------------------------------------------------------------------------>
![GENEVA]
##### [Main] | [Installation] | [User Guide] | [Tutorial] | [Index] #####
--------------------------------------------------------------------------------

Setup Files
============

For a numerically efficient generation of events, Geneva requires several setup
files, which are produced during the setup stage discussed in the [User Guide].
Here we explain what these files contain and what they are used for.

By default the setup files are located in the `setup` subdirectory. This
location can be changed with the `input_output::file_path::setup` option.

All equations and sections referred to below correspond to the paper describing
the Geneva calculation for Drell-Yan production in [arXiv:1508.01475].


Splitting function grids
-------------------------

Geneva requires normalized splitting probabilities P(Phi), as described in
section 2.B.4. Their efficient numerical implementation uses the veto method and
requires finding appropriate upper bounds according to the involved splitting.
These are contained in the files called
`<run_name>_<setup_tag>_split_ppV0To1_ISR.dat`,
`<run_name>_<setup_tag>_split_ppV1To2_ISR.dat`,
`<run_name>_<setup_tag>_split_ppV1To2_FSR.dat`.


Cross section information for combining spectrum and cumulant
--------------------------------------------------------------

To properly combine the Tau0 spectrum for Tau0 > Tau0cut with the cumulative
distribution up to Tau0 < Tau0cut and preserving the exact NNLO total cross
section, we use the method described in section 2.B.2 (see also equation 34).
This requires various pieces of information related to the integral of the
resummed calculation, which is given in the file
`<run_name>_<setup_tag>_profile.dat`.


Adaptive grids
---------------

An efficient phase-space generation requires integration grids. Since different
partonic channels can have very different singular structures, Geneva uses separate
grids for different partonic channels. The Drell-Yan calculation can use up to 41
different channels, lumping together some subleading partonic channels involving
similar PDFs. The integration grids are contained in files
`<run_name>_<setup_tag>_grid_<channel>.dat`.

To check the quality of the grid files, a graphical representation of them is
produced and written to the file `<run_name>_<setup_tag>_grid.pyplot`. To
produce a .pdf file of the relevant plots, run

    $ python <run_name>_<setup_tag>_grid.pyplot

Note that this requires the `matplotlib` Python module.

If the grids do not appear to look evenly distributed or the curves do not
appear to be smooth, re-running the setup stage with a larger number of
`<points>` and/or `<iterations>` is recommended.


[links]: #----------------------------------------------------------------------

[Main]:               ../README.md
[Installation]:       Installation.md
[User Guide]:         UserGuide.md
[Tutorial]:           tutorial/Tutorial.md
[Option Files]:       OptionFiles.md
[Index]:              Index.md
[GENEVA]:             geneva.jpg

[arXiv:1508.01475]:   http://arxiv.org/abs/arXiv:1508.01475
