<!------------------------------------------------------------------------------
# Author(s):
#    Simone Alioli, Christian Bauer, Frank Tackmann
#
# Copyright:
#    Copyright (C) 2017, 2018 Geneva Collaboration
#
#    This file is part of the Geneva MC framework. Geneva is distributed under
#    the terms of the GNU General Public License version 3 (GPLv3), see the
#    COPYING file that comes with this distribution for details.
#    Please respect the academic usage guidelines in the GUIDELINES file.
#
# Description:
#    Step-by-step tutorial how to perform a complete run
#------------------------------------------------------------------------------>
![GENEVA]
##### [Main] | [Installation] | [User Guide] | Tutorial | [Index] #####
--------------------------------------------------------------------------------


Tutorial
=========

This tutorial shows how to run Geneva from start to finish.

All paths in the following are relative to the Geneva root directory. It is
assumed that Geneva was built in the `build` directory, including the Python
interface, with the main Geneva Python script availabe in `build/bin/geneva`.
(See [Installation] for how to build.)

To start this tutorial make sure the `doc/tutorial` directory is clean and only
contains the provided example files `input.yml` and `pythia.cmnd` without any
modifications. Then go into

    $ cd doc/tutorial

and follow the steps below for each stage.

For this simple example, the job parallelization for each stage is achieved by
multiprocessing, assuming there are 4 cores available. To use a different number
of parallel jobs adjust the argument of `--num-runs` in the commands below (to
the same number for all stages). For more details on how to use MPI, see the
[User Guide].

Please note that the output of the individual jobs is redirected to separate log
files in `doc/tutorial/<stage>/log` subdirectories, with `<stage>` one of
`setup`, `generate`, `shower`, or `rivet`. Only a minimal amount of information
is written to the shell.

To see the commands that would be executed without actually executing them, add
the option `--dry-run` to any of the following commands, which will print the
commands as a list of lists. The commands inside each inner list would be
executed in parallel. Each outer list would advance to the next item only after
all the commands in the previous inner list have finished.


Setup stage
------------

Geneva first needs a setup run to obtain all information required for the
generation of events. These include the integration grids for adaptive phase
space sampling as well as other cross section related information. To execute
the setup, do

    tutorial$ ../../build/bin/geneva setup input.yml --points 200000 --iterations 3 --num-runs 4

This creates the following files in the `setup` subdirectory:
`tutorial_split_ppV0To1_ISR.dat`,
`tutorial_split_ppV1To2_ISR.dat`,
`tutorial_split_ppV1To2_FSR.dat`,
`tutorial_profile.dat`,
`tutorial_grid_*.dat`.
`tutorial_grid.pyplot`.

Do not modify or delete these files, as they are required for the next stage.
Their meaning is explained in [Setup Files]. There, you can also find
information on how to inspect the goodness of the setup run and what actions to
take in case of problems.

_Note that to be able to run this tutorial on a single machine in a reasonable
amount of time, the quality of the setup files produced here is very poor, and
they should not be used for production runs._ Recommended settings for
production runs are given in the [UserGuide].


Generate stage
---------------

The generate stage performs the generation of events. The command to execute is

    tutorial$ ../../build/bin/geneva generate input.yml --num-runs 4

This will create LHEF files named `tutorial_*.lhe[.gz]` in the `generate`
subdirectory. In addition to the actual events, these contain various
information in the comment sections at the beginning and end of the file. The
information at the beginning of each file includes all internal settings that
were used to create the file. The information included at the end is required to
extract the total cross section and merge different files.


Reweight stage
---------------

Since Geneva's NNLO calculation is based on N-jettiness subtractions, the
0-jet cross section with Tau0 < Tau0cut at order alpha_s^2 is only correct up to
small power-suppressed terms . To achieve exact NNLO accuracy, these
contributions have to be included separately, which is achieved by reweighting
the 0-jet events.

This requires to provide the exact NNLO cross section for Tau0 < Tau0cut, which
is used to determine the required power-suppressed terms and reweighting. The
values required for the example considered here are obtained from the table in
[NNLO Cross Section]. The three numbers for the scales mu, 2*mu, and mu/2 are
35.96, 55.97, and 14.27 pb.

Using this information, the reweighting of the 0-jet events is performed by

    tutorial$ ../../build/bin/geneva reweight input.yml --sigma-below 35.96 55.97 14.27 --num-runs 4

In addition to reweighting the 0-jet events in the LHEF files, this normalizes
all event weights to the final combined total cross section across all LHEF
files. The information on the reweighting and final total cross section is added
to the end of each file. The reweighted events overwrite the original events in
the `generate` subdirectory. Note that the low statistics used here yield an
O(10%) uncertainty on the total cross section, so the numbers in the files are
only indicative.


Shower stage
-------------

In the shower stage the generated events are showered with Pythia8, for which
an additional standard Pythia8 input file is used. The command to execute is

    tutorial$ ../../build/bin/geneva shower input.yml pythia.cmnd --num-runs 4

This produces [gzipped] HepMC event files with names `tutorial_*.hepmc[.gz]` in
the `shower` subdirectory. These can now be analyzed with your preferred tools.


Rivet stage
-------------

If Rivet is enabled (see [Installation]), the showered files can be analyzed
with Rivet through the provided analyze-rivet stage. An example command is

    tutorial$ ../../build/bin/geneva analyze-rivet shower/tutorial -a MC_ZINC -a MC_ZJETS --num-runs 4 --num-weights 1

One or more Rivet analyses to perform can be specified, together with the number
of weights to consider (default is 1, for central weight only). The weights
corresponding to different variations are analyzed in parallel, so the number of
runs must be at least as large as the number of weights times the number of
files. The command above produces YODA files with names `tutorial_*.yoda` in the
`rivet` subdirectory, one for each weight and seed. These can now be merged
and plotted with the standard tools distributed with Rivet.


[links]: #----------------------------------------------------------------------

[Main]:                 ../../README.md
[Installation]:         ../Installation.md
[User Guide]:           ../UserGuide.md
[Setup Files]:          ../SetupFiles.md
[NNLO Cross Section]:   ../NNLOCrossSection.md
[Index]:                ../Index.md
[GENEVA]:               ../geneva.jpg
