#-------------------------------------------------------------------------------
# Author(s):
#    Frank Tackmann
#
# Copyright:
#    Copyright (C) 2017, 2018 Geneva Collaboration
#
#    This file is part of the Geneva MC framework. Geneva is distributed under
#    the terms of the GNU General Public License version 3 (GPLv3), see the
#    COPYING file that comes with this distribution for details.
#    Please respect the academic usage guidelines in the GUIDELINES file.
#
# Description:
#    cmake version configuration file for Geneva.
#-------------------------------------------------------------------------------

# the default/fallback version number
set (PACKAGE_VERSION "1.0-RC3")

# Try to read more specific version information from git repository.
include (${CMAKE_CURRENT_LIST_DIR}/cmake/git-info.cmake)
get_git_info(${CMAKE_CURRENT_LIST_DIR} QUIET)

# Use the git version if we are at the root of a git repository.
if (GIT_COMMIT AND NOT GIT_PREFIX)
   if (GIT_VERSION VERSION_LESS PACKAGE_VERSION)
      # append version from git tag to pre-configured version
      set (PACKAGE_VERSION "${PACKAGE_VERSION}-${GIT_VERSION}")
   else ()
      # directly use git tag as the version
      set (PACKAGE_VERSION ${GIT_VERSION})
   endif ()
endif ()

# If called from find_package, check whether the requested PACKAGE_FIND_VERSION
# is compatible and return.
if (PACKAGE_FIND_NAME)
   if (PACKAGE_VERSION VERSION_LESS PACKAGE_FIND_VERSION)
      set(PACKAGE_VERSION_COMPATIBLE false)
   else ()
      set (PACKAGE_VERSION_COMPATIBLE true)
      if (PACKAGE_VERSION VERSION_EQUAL PACKAGE_FIND_VERSION)
         set (PACKAGE_VERSION_EXACT true)
      endif ()
   endif ()
else ()
   set (geneva_VERSION ${PACKAGE_VERSION})
   unset (PACKAGE_VERSION)
endif ()
