//------------------------------------------------------------------------------
/// \file AnalyzerFactory.hpp
//
// Author(s):
//    Simone Alioli
//
// Copyright:
//    Copyright (C) 2012 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interface of class AnalyzerFactory
//------------------------------------------------------------------------------

#ifndef GENEVA_ANALYZER_FACTORY_HPP
#define GENEVA_ANALYZER_FACTORY_HPP

#include "Geneva/Core/Utils/Singleton.hpp"

#include <vector>

namespace Geneva
{

class IAnalyzer;
class OptionMap;

//------------------------------------------------------------------------------
/**
 * \class AnalyzerFactory
 * \ingroup analyzer
 *
 * \brief The %AnalyzerFactory is responsible for creating Analyzer objects.
 *
 * Uses options from an OptionMap to determine which Analyzer to use.
 */
//------------------------------------------------------------------------------
class AnalyzerFactory : public Singleton<AnalyzerFactory>
{
   private:
      std::vector<IAnalyzer*> _toDelete;

   public:
      /// Given options in optionMap, create a specific Analyzer object
      IAnalyzer*  getAnalyzer(const OptionMap& optMap);

      IAnalyzer*  getInternalAnalyzer(const OptionMap& optMap);

   protected:
      friend class Singleton<AnalyzerFactory>;

   public:
      ~AnalyzerFactory();
};

} // namespace Geneva

#endif // GENEVA_ANALYZER_FACTORY_HPP
