//------------------------------------------------------------------------------
/// \file AnalyzerRates.hpp
//
// Author(s):
//    Jon Walsh, Simone Alioli
//
// Copyright:
//    Copyright (C) 2012 LBL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interface of class AnalyzerRates
//------------------------------------------------------------------------------

#ifndef GENEVA_ANALYZER_RATES_HPP
#define GENEVA_ANALYZER_RATES_HPP

#include "Geneva/Analyzers/AnalyzerBase.hpp"

namespace Geneva
{

class OptionMap;

//------------------------------------------------------------------------------
/**
 * \class AnalyzerRates
 * \ingroup Analyzers
 *
 * \brief Lightweight e+e- and pp analyzer for parton level and pythia events.
 *
 * Contains N-jet rates.
 */
//------------------------------------------------------------------------------
class AnalyzerRates : public AnalyzerBase
{
   private:
      double _tauNcut;
      double _tauNplusOnecut;
      bool _eeCollider;           ///< whether it is a e-e+ collision

   public:
      AnalyzerRates(const OptionMap& optmap);

      virtual std::string name() const { return "AnalyzerRates"; }

   private:
      void addSingleBins(Level level);
      virtual void analyzeBase(const Event& event, Level level);
};

} // namespace Geneva

#endif // GENEVA_ANALYZER_RATES_HPP
