//------------------------------------------------------------------------------
/// \file CalculationFactory.hpp
//
// Author(s):
//    Chris Vermilion
//
// Copyright:
//    Copyright (C) 2012 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interface of class CalculationFactory
//------------------------------------------------------------------------------

#ifndef GENEVA_CALCULATION_FACTORY_HPP
#define GENEVA_CALCULATION_FACTORY_HPP

#include "Geneva/Core/Utils/Singleton.hpp"

#include <vector>

namespace Geneva
{

class ICalculation;
class OptionMap;
class SignatureSet;

//------------------------------------------------------------------------------
/**
 * \class CalculationFactory
 * \ingroup calc
 *
 * \brief The %CalculationFactory is responsible for creating Calculation objects.
 *
 * Uses options from an OptionMap to determine which Calculation to use, and
 * what their components should be.
 */
//------------------------------------------------------------------------------
class CalculationFactory : public Singleton<CalculationFactory>
{
   private:
      std::vector<ICalculation*> _toDelete;

   public:
      /// Given options in optionMap, create a specific Calculation object
      ICalculation* getCalculation(const OptionMap& optionMap);

   protected:
      friend class Singleton<CalculationFactory>;

   public:
      ~CalculationFactory();
};

} // namespace Geneva

#endif // GENEVA_CALCULATION_FACTORY_HPP
