//------------------------------------------------------------------------------
/// \file PhiNLOppVFKS.hpp
//
// Author(s):
//    Simone Alioli, Chris Vermilion
//
// Copyright:
//    Copyright (C) 2012 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interface of PhiNLOppVFKS class
//------------------------------------------------------------------------------

#ifndef GENEVA_PHI_NLO_PPV_FKS_HPP
#define GENEVA_PHI_NLO_PPV_FKS_HPP

#include "Geneva/Calculations/PhiNLOppFKSBase.hpp"

namespace Geneva
{

//------------------------------------------------------------------------------
/**
 * \class PhiNLOppVFKS
 * \ingroup calc
 *
 * \brief Defines Phi0 for pp -> V at NLO using FKS projections
 */
//------------------------------------------------------------------------------
class PhiNLOppVFKS : public PhiNLOppFKSBase
{
   private:
      double _tau0Cut;

   public:
      PhiNLOppVFKS(double Tau0cut, double cmEnergy, double fksTinyCut)
         : PhiNLOppFKSBase(cmEnergy, fksTinyCut), _tau0Cut(Tau0cut) {}

      /// Checks if a Configuration is N-body and part of Phi_N.
      virtual bool isPhiN(const Configuration& configN) const;

      /// Checks if a Configuration is (N+1)-body and part of Phi_{N+1}.
      virtual bool isPhiNplus1(const Configuration& configNp1) const;

      virtual size_t countN(const Configuration& config) const;

      virtual const std::string name() const;

      virtual bool ThetaijRij(PhiNplus1 phiNp1CM) const;

      virtual bool ThetaijRijSoft(const Configuration& configNCM, const Configuration::iterator emitter, const FourVector& pSoft) const;
};

} // namespace Geneva

#endif // GENEVA_PHI_NLO_PPV_FKS_HPP
