//------------------------------------------------------------------------------
/// \file PhiNLOppVjFKS.hpp
//
// Author(s):
//    Simone Alioli
//
// Copyright:
//    Copyright (C) 2012 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interfaces of PhiNLOppVjFKS classes
//------------------------------------------------------------------------------

#ifndef GENEVA_PHI_NLO_PPVJ_FKS_HPP
#define GENEVA_PHI_NLO_PPVJ_FKS_HPP

#include "Geneva/Calculations/PhiNLOppVjBase.hpp"
#include "Geneva/Calculations/PhiNLOppFKSBase.hpp"

namespace Geneva
{

//------------------------------------------------------------------------------
/**
 * \class PhiNLOppVjFKS
 * \ingroup calc
 *
 * \brief Defines Phi1 for p p -> V jet at NLO using FKS mapping
 *
 * \todo document me!
 */
//------------------------------------------------------------------------------
class PhiNLOppVjFKS : public PhiNLOppVjBase, public PhiNLOppFKSBase
{
   public:
      PhiNLOppVjFKS(double Tau0cut, double Tau1cut, const SignatureSet& sigSet, double cmEnergy, double fksTinyCut)
         : PhiNLOppVjBase(Tau0cut, Tau1cut, sigSet, cmEnergy), PhiNLOppFKSBase(cmEnergy, fksTinyCut) {};

      virtual const std::string name() const;

      virtual bool ThetaijRij(PhiNplus1 phiNp1CM) const
      {
         return Rij(phiNp1CM) && Thetaij(phiNp1CM);
      }

   protected:
      virtual bool projectionOutsideMapBoundaries(PhiNplus1 phiNp1CM, double xA, double xB) const;
};


////////////////////////////////////////////////////////////////////////////////
// Inline Definitions
////////////////////////////////////////////////////////////////////////////////

//------------------------------------------------------------------------------
inline const std::string PhiNLOppVjFKS::name() const
{
   return "PhiNLOppVjFKS";
}

} // namespace Geneva

#endif // GENEVA_PHI_NLO_PPVJ_FKS_HPP
