//------------------------------------------------------------------------------
/// \file ComponentFactory.hpp
//
// Author(s):
//    Chris Vermilion, Frank Tackmann
//
// Copyright:
//    Copyright (C) 2012 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interface of class ComponentFactory
//------------------------------------------------------------------------------

#ifndef GENEVA_COMPONENT_FACTORY_HPP
#define GENEVA_COMPONENT_FACTORY_HPP

#include "Geneva/Core/Physics/PdgID.hpp"
#include "Geneva/Core/Utils/Singleton.hpp"

namespace Geneva
{

class OptionMap;
class ITreeME;
class ITreeMEComplete;
class ITreeMEColor;
class IOneLoopME;
class ICoupling;
class CouplingStrong;
class IPDF;
class IScale;

/// \defgroup comp Components

//------------------------------------------------------------------------------
/**
 * \class ComponentFactory
 * \ingroup comp
 *
 * \brief Factory for common components, in particular matrix elements.
 */
//------------------------------------------------------------------------------
class ComponentFactory : public Singleton<ComponentFactory>
{
   public:
      ITreeME*         getTreeME(const OptionMap& optMap);
      ITreeMEComplete* getTreeMEComplete(const OptionMap& optMap);
      ITreeMEColor*    getTreeMEColor(const OptionMap& optMap);
      IOneLoopME*      getOneLoopME(const OptionMap& optMap);
      CouplingStrong*  getCouplingStrong(const OptionMap& optMap);
      ICoupling*       getCouplingEM(const OptionMap& optMap);
      IPDF*            getPDF(const OptionMap& optMap);
      IScale*          getRenormalizationScale(const OptionMap& optMap);
      IScale*          getFactorizationScale(const OptionMap& optMap);

      static IPDF* makePDF(PdgID beamA, PdgID beamB, const std::string& name,
                           int member = 0, size_t maxStackLength = 0);

   protected:
      friend class Singleton<ComponentFactory>;
      ComponentFactory() {};
};

} // namespace Geneva

#endif // GENEVA_COMPONENT_FACTORY_HPP
