//------------------------------------------------------------------------------
/// \file FluxFactor.hpp
//
// Author(s):
//    Christian Bauer, Chris Vermilion
//
// Copyright:
//    Copyright (C) 2012 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interface of class FluxFactor
//------------------------------------------------------------------------------

#ifndef GENEVA_FLUX_FACTOR_HPP
#define GENEVA_FLUX_FACTOR_HPP

#include <string>

namespace Geneva
{

class Configuration;
class SignatureSet;

//------------------------------------------------------------------------------
/**
 * \ingroup Components
 * \brief   Computes the flux factor for a given configuration.
 *
 * Uses a simple analytical formula for two beams colliding head-on. It works
 * for incoming particles of arbitrary mass.
 *
 * \note Assumes that the configuration has two initial particles.
 */
//------------------------------------------------------------------------------
class FluxFactor
{
   public:
      /// Returns the flux factor for \a config.
      double operator()(const Configuration& config) const;

      /// Checks compatibility with the given SignatureSet.
      int checkCompatibility(const SignatureSet& sigSet) const;

      std::string name() const;
};


////////////////////////////////////////////////////////////////////////////////
// Inline Definitions
////////////////////////////////////////////////////////////////////////////////

//------------------------------------------------------------------------------
inline std::string FluxFactor::name() const
{
   return "FluxFactor";
}

} // namespace Geneva

#endif // GENEVA_FLUX_FACTOR_HPP
