//------------------------------------------------------------------------------
/// \file OneLoopMEOpenLoops.hpp
//
// Author(s):
//    Simone Alioli
//
// Copyright:
//    Copyright (C) 2012 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.

// Description:
//    Definition of class OneLoopMEOpenLoops
//------------------------------------------------------------------------------

#ifndef GENEVA_ONE_LOOP_ME_OPENLOOPS_HPP
#define GENEVA_ONE_LOOP_ME_OPENLOOPS_HPP

#include "Geneva/Components/IOneLoopME.hpp"

#include <string>

namespace Geneva
{

class Configuration;
class SignatureSet;
class OptionMap;

//------------------------------------------------------------------------------
/**
 * \class OneLoopMEOpenLoops
 * \ingroup gen
 *  Implementation of the OneLoopMEOpenLoops interface
 */
//------------------------------------------------------------------------------
class OneLoopMEOpenLoops : virtual public IOneLoopME
{
   public:
      OneLoopMEOpenLoops(const OptionMap& optMap);

      virtual double getDoublePole(const Configuration& config) const;
      virtual double getSinglePole(const Configuration& config) const;
      virtual double getFiniteTerm(const Configuration& config) const;
      virtual bool   getAllTerms(const Configuration& config,
                                 double& doublePole,
                                 double& singlePole,
                                 double& finiteTerm) const;
      virtual bool checkCompatibility(const SignatureSet& sigSet) const;
      virtual std::string name() const;
};

////////////////////////////////////////////////////////////////////////////////
// Inline Definitions
////////////////////////////////////////////////////////////////////////////////

//------------------------------------------------------------------------------
inline bool OneLoopMEOpenLoops::checkCompatibility(const SignatureSet& sigSet) const
{
   //TODO: remove this function ? never used and doing nothing
   return false;
}

} // namespace Geneva

#endif // GENEVA_ONE_LOOP_ME_OPENLOOPS_HPP
