//------------------------------------------------------------------------------
/// \file OpenLoopsInterface.hpp
//
// Author(s):
//    Simone Alioli
//
// Copyright:
//    Copyright (C) 2012 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.

// Description:
//    Definition of class OpenLoopsInterface
//------------------------------------------------------------------------------

#ifndef GENEVA_OPENLOOPS_INTERFACE_HPP
#define GENEVA_OPENLOOPS_INTERFACE_HPP

#include "Geneva/Core/Physics/Signature.hpp"
#include "Geneva/Core/UI/OptionMap.hpp"
#include "Geneva/Core/Utils/Singleton.hpp"

#include <map>

namespace Geneva
{

class Configuration;
class SignatureSet;

//------------------------------------------------------------------------------
/**
 * \class OpenLoopsInterface
 * \ingroup gen
 *  Implementation of the OpenLoopsInterface interface
 */
//------------------------------------------------------------------------------
class OpenLoopsInterface : virtual public Singleton<OpenLoopsInterface>
{
   public:
      enum AmplitudeType
      {
         kTree = 0,
         kLoop,
         kLoopSq,
         kUVct,
         kAmplitudeTypeLEN
      };

   private:
      typedef std::map<Signature, int> _codes_map_type;
      bool _isInitialized {false};
      OptionMap _optMap;
      std::vector<_codes_map_type> _codesMaps;

   public:
      OpenLoopsInterface();
      ~OpenLoopsInterface();

      void addTreeProcesses(const OptionMap& optMap);
      void addLoopProcesses(const OptionMap& optMap);
      void addLoopInducedProcesses(const OptionMap& optMap);

      void evaluateTree(const Configuration& config, double renormScale, double alphaS, double alphaEM, double* m2);

      void evaluateTreeLargeNc(const Configuration& config, double renormScale, double alphaS, double alphaEM, double* m2);

      std::map<Signature, std::vector<std::vector<std::pair<int,int> > > > getColorFlowBasis();

      void evaluateTreeComplete(const Configuration& config, double renormScale, double alphaS, double alphaEM, double* m2, double* m2cc, double* m2munu, double* m2ccew);

      void evaluateLoop(const Configuration& config, double renormScale, double alphaS, double alphaEM, double* m2Tree, double* m2Loop, double* acc);

   protected:
      void initialize();
      void finalize();

      void configToOpenLoops(const Configuration& config, double* allmomenta) const;
};

} // namespace Geneva

#endif // GENEVA_OPENLOOPS_INTERFACE_HPP
