//------------------------------------------------------------------------------
/// \file SplittingMappingBase.hpp
//
// Author(s):
//    Christian Bauer, Frank Tackmann
//
// Copyright:
//    Copyright (C) 2016 LBNL, DESY
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interface of class SplittingMappingBase
//------------------------------------------------------------------------------

#ifndef GENEVA_SPLITTING_MAPPING_BASE_HPP
#define GENEVA_SPLITTING_MAPPING_BASE_HPP

#include "Geneva/Components/ISplittingMapping.hpp"
#include "Geneva/Components/RegionInfoList.hpp"

#include "Geneva/Core/Physics/SignatureSet.hpp"

namespace Geneva
{

//------------------------------------------------------------------------------
/**
 * \class SplittingMappingBase
 *
 * \brief brief description goes here.
 *
 * \todo: detailed description goes here.
 */
//------------------------------------------------------------------------------
class SplittingMappingBase : public virtual ISplittingMapping
{
   protected:
      double _cmEnergy;
      SignatureSet _signaturesNmin1;
      SignatureSet _signaturesN;
      RegionInfoList _regionsInfo;

   public:
      SplittingMappingBase() : _cmEnergy(std::numeric_limits< double >::quiet_NaN()) {};

      //Return the complete RegionInfoList
      RegionInfoList getRegionInfoList();

      //Return the set of N-body signatures
      SignatureSet sigsN();
      //Return the set of (N-1)-body signatures
      SignatureSet sigsNmin1();

      //Return the allowed splittings given a RegionInfo
      virtual std::list<RegionInfo> getAllowedSplittings(const RegionInfo& map);
      //Return the allowed projections given a RegionInfo
      virtual std::list<RegionInfo> getAllowedProjections(const RegionInfo& map);
};

} // namespace Geneva

#endif // GENEVA_SPLITTING_MAPPING_BASE_HPP
