//------------------------------------------------------------------------------
/// \file TreeMECompleteOpenLoops.hpp
//
// Author(s):
//    Simone Alioli
//
// Copyright:
//    Copyright (C) 2012 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.

// Description:
//    Definition of class TreeMECompleteOpenLoops
//------------------------------------------------------------------------------

#ifndef GENEVA_TREE_ME_COMPLETE_OPENLOOPS_HPP
#define GENEVA_TREE_ME_COMPLETE_OPENLOOPS_HPP

#include "Geneva/Components/ITreeMEComplete.hpp"

#include <string>
#include <vector>

namespace Geneva
{

class Configuration;
class SignatureSet;
class OptionMap;

//------------------------------------------------------------------------------
/**
 * \class TreeMECompleteOpenLoops
 * \ingroup gen
 *  Implementation of the TreeMECompleteOpenLoops interface
 */
//------------------------------------------------------------------------------
class TreeMECompleteOpenLoops : public ITreeMEComplete
{
   public:
      TreeMECompleteOpenLoops(const OptionMap& optMap);

      /// Calculates all required information for a given Configuraton.
      virtual void calculate(const Configuration& config);
      /// Returns the squared tree-level matrix element for the last calculated configuration.
      virtual double value() const;
      /// Returns the color matrix for the given configuration
      virtual double colorMatrix(Configuration::const_iterator i, Configuration::const_iterator j) const;
      /// Returns the polarization matrix for the given configuration and leg i
      virtual double polarizationMatrix(Configuration::const_iterator i, lorentzIndex mu, lorentzIndex nu) const;
      /// Checks compatibility with the given SignatureSet.
      virtual int checkCompatibility(const SignatureSet& sigSet) const;
      /// Returns the name of the tree-level matrix element.
      virtual const std::string name() const;

   private:
      double _value;                       ///< the value of the squared matrix element
      std::vector<double> _ccvalue;
      std::vector<double> _scvalue;
      const Configuration* _config;
};


////////////////////////////////////////////////////////////////////////////////
// Inline Definitions
////////////////////////////////////////////////////////////////////////////////

//------------------------------------------------------------------------------
inline double TreeMECompleteOpenLoops::value() const
{
   return _value;
}

//------------------------------------------------------------------------------
inline int TreeMECompleteOpenLoops::checkCompatibility(const SignatureSet& sigSet) const
{
  //TODO: remove this function ? never used and doing nothing
   return 0;
}

} // namespace Geneva

#endif // GENEVA_TREE_ME_OPENLOOPS_HPP
