//------------------------------------------------------------------------------
/// \file ConfigurationUtils.hpp
//
// Author(s):
//    Frank Tackmann
//
// Copyright:
//    Copyright (C) 2014 Frank Tackmann
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Utility functions for checking numerical accuracy of Configurations
//------------------------------------------------------------------------------

#ifndef GENEVA_CONFIGURATION_UTILS_HPP
#define GENEVA_CONFIGURATION_UTILS_HPP

#include "Geneva/Core/Physics/Configuration.hpp"

namespace Geneva
{

// Checks four-momentum conservation for a Configuration.
bool checkMomentumConservation(const Configuration& config, double precision, double accuracy);

// Checks on-shell conditions for all Particles in a Configuration.
bool checkOnShellConditions(const Configuration& config, double precision, double accuracy);

// Checks if a Configuration is in its CM frame.
bool isInCoMFrame(const Configuration& config, double precision, double accuracy);

// Enforces a physical configuration.
bool enforceMomentumConservation(Configuration& config, std::string where,
                                 double precision, double accuracy, double buffer = 10.);

} // namespace Geneva

#endif // GENEVA_CONFIGURATION_UTILS_HPP
