//------------------------------------------------------------------------------
/// \file IRestriction.hpp
//
// Author(s):
//    Chris Vermilion
//
// Copyright:
//    Copyright (C) 2012 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interface of class Restriction
//------------------------------------------------------------------------------

#ifndef GENEVA_IRESTRICTION_HPP
#define GENEVA_IRESTRICTION_HPP

#include <cstdlib>

namespace Geneva
{

class Configuration;

//------------------------------------------------------------------------------
/**
 * \class IRestriction
 * \ingroup core
 *
 * \brief Interface for generic phase-space restrictions.
 */
//------------------------------------------------------------------------------
class IRestriction
{
   public:
      IRestriction() = default;
      IRestriction(const IRestriction&) = delete;
      IRestriction(IRestriction&&) = delete;
      IRestriction& operator=(const IRestriction&) = delete;
      IRestriction& operator=(IRestriction&&) = delete;
      virtual ~IRestriction() = default;

      /// Determines if a Configuration is in the Restriction.
      virtual bool contains(const Configuration& configuration) = 0;
      virtual size_t countJets(const Configuration& configuration) const = 0;

      virtual IRestriction* clone() const = 0;
};

} // namespace Geneva

#endif // GENEVA_IRESTRICTION_HPP
