//------------------------------------------------------------------------------
/// \file Order.hpp
//
// Author(s):
//    Frank Tackmann
//
// Copyright:
//    Copyright (C) 2012 MIT, Frank Tackmann
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Definitions of fixed and running orders
//------------------------------------------------------------------------------

#ifndef GENEVA_ORDER_HPP
#define GENEVA_ORDER_HPP

namespace Geneva
{

//------------------------------------------------------------------------------
/**
 * \class FixedOrder
 * \ingroup Core
 *
 * \brief Named constants to specify fixed orders.
 *
 * \note This is a temporary workaround until we can use C++11 enum class.
 */
//------------------------------------------------------------------------------
class FixedOrder
{
   public:
      enum Value
      {
         kNone = -1,
         kLO = 0,
         kNLO = 1,
         kNNLO = 2
      };

   private:
      Value _value;

   public:
      FixedOrder() : _value(kLO) {}
      FixedOrder(FixedOrder::Value value) : _value(value) {}

      operator int() const { return _value; }
};


//------------------------------------------------------------------------------
/**
 * \class RunOrder
 * \ingroup Core
 *
 * \brief Named constants to specify running orders.
 *
 * \note This is a temporary workaround until we can use C++11 enum class.
 */
//------------------------------------------------------------------------------
class RunOrder
{
   public:
      enum Value
      {
         kNone = -1,
         kLL = 0,
         kNLL = 1,
         kNNLL = 2
      };

   private:
      Value _value;

   public:
      RunOrder() : _value(kLL) {}
      RunOrder(RunOrder::Value value) : _value(value) {}

      operator int() const { return _value; }
};

} // namespace Geneva

#endif // GENEVA_ORDER_HPP
