//------------------------------------------------------------------------------
/// \file OptionParserLHEFHeader.hpp
//
// Author(s):
//    Christian Bauer
//
// Copyright:
//    Copyright (C) 2012 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Definition of class OptionParserLHEFHeader
//------------------------------------------------------------------------------

#ifndef GENEVA_OPTION_PARSER_LHEF_HEADER_HPP
#define GENEVA_OPTION_PARSER_LHEF_HEADER_HPP

#include <iosfwd>
#include <string>
#include <deque>
#include <utility>

namespace Geneva
{

//------------------------------------------------------------------------------
/**
 * \class OptionParserLHEFHeader
 * \ingroup Core
 *
 * \brief Class to parse the header of an LHEF file for options
 */
//------------------------------------------------------------------------------
class OptionParserLHEFHeader
{
   private:
      typedef std::deque<std::pair<std::string, std::string> > _impl_type;
      _impl_type _options;

   public:
      typedef _impl_type::const_iterator const_iterator;

      OptionParserLHEFHeader(std::istream& optionStringStream);

      OptionParserLHEFHeader(const std::string& optionString);

      /// Checks if there are more options to retrieve.
      bool hasNext() const;

      /// Checks if a specific option is present.
      bool hasOption(const std::string& name) const;

      /// Gets the next option, assuming we are SETTING options.
      void getNext(std::string& name, std::string& value);

      /// Finds a specific option.
      bool find(const std::string& name, const_iterator& it) const;

   private:
      void parse(std::istream& in);
};


////////////////////////////////////////////////////////////////////////////////
// Inline Definitions
////////////////////////////////////////////////////////////////////////////////

//------------------------------------------------------------------------------
inline bool OptionParserLHEFHeader::hasNext() const
{
   return !_options.empty();
}

} // namespace Geneva

#endif // GENEVA_OPTION_PARSER_LHEF_HEADER_HPP
