//------------------------------------------------------------------------------
/// \file OptionParserYAML.hpp
//
// Author(s):
//    Christian Bauer, Frank Tackmann
//
// Copyright:
//    Copyright (C) 2017 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interface of class OptionParserYAML
//------------------------------------------------------------------------------

#ifndef GENEVA_OPTION_PARSER_YAML_HPP
#define GENEVA_OPTION_PARSER_YAML_HPP

#include <string>
#include <vector>

namespace Geneva_YAML
{
class Node;
}

namespace Geneva
{

class OptionBase;

//------------------------------------------------------------------------------
/**
 * \class OptionParserYAML
 * \ingroup Core
 *
 * \brief Class to parse options from a .yml options file.
 */
//------------------------------------------------------------------------------
class OptionParserYAML
{
   private:
      std::vector< std::pair<std::string, std::string> > _optionList;
      std::vector< std::pair<std::string, std::string> >::iterator _currentOption;

   public:
      OptionParserYAML(const std::string& file);

      // Checks if there more options to retrieve.
      bool hasNext() const;

      // Gets the next option.
      void getNext(std::string& name, std::string& val);

      // Gets the next option.
      OptionBase* getNext();

   private:
      // Parses one option at a time.
      void parseOption(const std::string& name, const Geneva_YAML::Node& node);

      // Adds the option with key \a name and value \a value.
      void addOption(std::string name, std::string value);
};

} // namespace Geneva

#endif // GENEVA_OPTION_PARSER_YAML_HPP
