//------------------------------------------------------------------------------
/// \file CatchSignal.hpp
//
// Author(s):
//    Simone Alioli
//
// Copyright:
//    Copyright (C) 2017 UNIMIB
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//     Interface of class CatchSignal
//------------------------------------------------------------------------------

#ifndef GENEVA_CATCH_SIGNAL_HPP
#define GENEVA_CATCH_SIGNAL_HPP

#include <signal.h>

namespace Geneva
{

//------------------------------------------------------------------------------
/**
 * \class CatchSignal
 * \ingroup Core
 *
 * \brief Catches a system signal and performs appropriate action.
 *
 * Only supports interrupt signal (SIGINT), which is generated by CTRL+C or
 * using 'kill -2' with ungraceful termination for now.
 */
//------------------------------------------------------------------------------
class CatchSignal
{
   public:
      CatchSignal(int signal = SIGINT);
      ~CatchSignal();

      CatchSignal(const CatchSignal&) = delete;
      CatchSignal(CatchSignal&&) = delete;
      CatchSignal& operator=(const CatchSignal&) = delete;
      CatchSignal& operator=(CatchSignal&&) = delete;

   private:
      static void _handler(int signal);

      struct sigaction _old_handler;
};

} // namespace Geneva

#endif // GENEVA_CATCH_SIGNAL_HPP
