//------------------------------------------------------------------------------
/// \file EventGeneratorAdaptivePartialUnweighted.hpp
//
// Author(s):
//    Christian Bauer, Frank Tackmann
//
// Copyright:
//    Copyright (C) 2016 LBNL, Frank Tackmann
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interface of class EventGeneratorAdaptivePartialUnweighted
//------------------------------------------------------------------------------

#ifndef GENEVA_EVENT_GENERATOR_ADAPTIVE_PARTIAL_UNWEIGHTED_HPP
#define GENEVA_EVENT_GENERATOR_ADAPTIVE_PARTIAL_UNWEIGHTED_HPP

#include "Geneva/Driver/EventGeneratorAdaptive.hpp"

namespace Geneva
{

//------------------------------------------------------------------------------
/**
 * \class EventGeneratorAdaptivePartialUnweighted
 * \ingroup EventGenerator
 *
 * \brief Generates partially unweighted events.
 *
 * Generates partially unweighted events using the same grid optimization of
 * EventGeneratorAdaptive, and in addition partially unweights the generated
 * events against a fixed target weight.
 */
//------------------------------------------------------------------------------
class EventGeneratorAdaptivePartialUnweighted : public EventGeneratorAdaptive
{
   private:
      double _targetWeight;            ///< The target weight to reweight against.

   public:
      EventGeneratorAdaptivePartialUnweighted(IGenerator* gen, ICalculation* calc, const OptionMap& optMap);

   private:
      // Creates one partially unweighted event.
      virtual void next(ChannelIterator channel, double channelWeight);

      // Obtains an estimate of the total cross section.
      double getCrossSectionEstimate(double precision);
};

} // namespace Geneva

#endif // GENEVA_EVENT_GENERATOR_ADAPTIVE_PARTIAL_UNWEIGHTED_HPP
