//------------------------------------------------------------------------------
/// \file IEventGenerator.hpp
//
// Author(s):
//    Christian Bauer
//
// Copyright:
//    Copyright (C) 2013 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Base class for an Event Generator
//------------------------------------------------------------------------------

#ifndef GENEVA_I_EVENT_GENERATOR_HPP
#define GENEVA_I_EVENT_GENERATOR_HPP

#include <cstdlib>

namespace Geneva
{

class IGenerator;
class Event;
class Rate;

//------------------------------------------------------------------------------
/**
 * \class IEventGenerator
 * \ingroup Driver
 *
 * \brief Interface for an Event Generator
 *
 * Generates events, one at a time.
 */
//------------------------------------------------------------------------------
class IEventGenerator
{
   public:
      virtual ~IEventGenerator() = default;

      virtual const Event& next() = 0;

      /// Finalize internal components, like Generators or Calculations
      virtual void finalize(const size_t numEvents) = 0;

      /// Returns the total rate generated
      virtual const Rate& totalRate() const = 0;

   protected:
      IEventGenerator() = default;
      IEventGenerator(const IEventGenerator&) = default;
      IEventGenerator(IEventGenerator&&) = default;
      IEventGenerator& operator=(const IEventGenerator&) = default;
      IEventGenerator& operator=(IEventGenerator&&) = default;
};

} // namespace Geneva

#endif // GENEVA_I_EVENT_GENERATOR_HPP
