//------------------------------------------------------------------------------
/// \file GeneratorFactory.hpp
//
// Author(s):
//    Chris Vermilion
//
// Copyright:
//    Copyright (C) 2012 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interface of class GeneratorFactory
//------------------------------------------------------------------------------

#ifndef GENEVA_GENERATOR_FACTORY_HPP
#define GENEVA_GENERATOR_FACTORY_HPP

#include "Geneva/Core/Utils/Singleton.hpp"

#include <vector>
#include <string>

namespace Geneva
{

class IGenerator;
class OptionMap;

//------------------------------------------------------------------------------
/// Responsible for creating Generator objects
/// \ingroup gen
//------------------------------------------------------------------------------
class GeneratorFactory : public Singleton<GeneratorFactory>
{
   private:
      std::vector<IGenerator*> _toDelete;

   public:
      /// Given options in optionMap, create a Generator.  name overrides the Generator name in optionMap.
      IGenerator* getGenerator(const OptionMap& optionMap, std::string name = "");

      ~GeneratorFactory();

   protected:
      friend class Singleton<GeneratorFactory>;
};

} // namespace Geneva

#endif // GENEVA_GENERATOR_FACTORY_HPP
