//------------------------------------------------------------------------------
/// \file IntegrationChannelManager.hpp
//
// Author(s):
//    Simone Alioli
//
// Copyright:
//    Copyright (C) 2015 CERN
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interface of class IntegrationChannelManager
//------------------------------------------------------------------------------

#ifndef GENEVA_INTEGRATION_CHANNEL_MANAGER_HPP
#define GENEVA_INTEGRATION_CHANNEL_MANAGER_HPP

#include <vector>
#include <map>
#include <iosfwd>

namespace Geneva
{

class IntegrationChannel;
class SignatureSet;
class OptionMap;
class Signature;

//------------------------------------------------------------------------------
/**
 * \class IntegrationChannelManager
 * \ingroup comp
 *
 * \brief Provides Integrations channels for specific requirements.
 */
//------------------------------------------------------------------------------
class IntegrationChannelManager
{
   public:
      std::vector<IntegrationChannel> getChannels(const SignatureSet& sigSet, const OptionMap& optMap);
      std::map<Signature, std::string> getSignatureMap(const SignatureSet& sigSet, const OptionMap& optMap);
};

} // namespace Geneva

#endif // GENEVA_INTEGRATION_CHANNEL_MANAGER_HPP
