//------------------------------------------------------------------------------
/// \file PythiaUtils.hpp
//
// Author(s):
//    Frank Tackmann, Calvin Berggren
//
// Copyright:
//    Copyright (C) 2012 Frank Tackmann, LBL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Basic algorithms needed for the interface with Pythia.
//------------------------------------------------------------------------------

#ifndef GENEVA_PYTHIA_UTILS_HPP
#define GENEVA_PYTHIA_UTILS_HPP

#include "Geneva/Core/Physics/Particle.hpp"

#include <string>
#include <vector>
#include <limits>

namespace Pythia8
{
class Event;
}

namespace Geneva
{

class Configuration;

void fullEventToConfig(const Pythia8::Event& event, Configuration& config);
void partonLevelToConfig(const Pythia8::Event& event, Configuration& config, bool removeMPI, double pTminMPI = 0.0);
void processToConfig(const Pythia8::Event& event, Configuration& config);

double calculateTauNPythia(const Pythia8::Event& event, bool sumContributions = false);
double calculateTauNppPythia(const Pythia8::Event& event, double y, bool sumContributions, bool useHardDirections);

} // namespace Geneva

#endif // GENEVA_PYTHIA_UTILS_HPP
