//------------------------------------------------------------------------------
/// \file GenevaWrapper.hpp
//
// Author(s):
//    Simone Alioli
//
// Copyright:
//    Copyright (C) 2017 CERN
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Wrappers to Geneva main functions
//------------------------------------------------------------------------------

#ifndef GENEVA_WRAPPER_HPP
#define GENEVA_WRAPPER_HPP

#include "Geneva/config.hpp"

#include "Geneva/Core/Utils/Singleton.hpp"

#include <string>

namespace Geneva
{

class GenerationReport;
class IAnalyzer;

class GenevaWrapper : public Singleton<GenevaWrapper>
{
   public:
      int setupCrossSection(const std::string& options);

      int generateEvents(const std::string& exeName, const std::string& options);

#ifdef geneva_USE_PYTHIA8
      int analyzeLhef(const std::string& exeName, const std::string& options);

      int showerPythia8(const std::string& exeName, const std::string& options);
#endif

#ifdef geneva_USE_RIVET
      int analyzeRivet(const std::string& exeName, const std::string& options);
#endif

   protected:
      friend class Singleton<GenevaWrapper>;

   private:
      void writeReport(GenerationReport& report, const std::string& filename,
                       double runtime, size_t numEvents, IAnalyzer* analyzer);
};

} // namespace Geneva

#endif // GENEVA_WRAPPER_HPP
