//------------------------------------------------------------------------------
/// \file ConvBase.hpp
//
// Author(s):
//    Jon Walsh, Frank Tackmann
//
// Copyright:
//    Copyright (C) 2017  DESY
//
//    This file is part of the SCETlib library. SCETlib is distributed under the
//    terms of the GNU General Public License version 3 (GPLv3), see the COPYING
//    file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interface of class ConvBase
//------------------------------------------------------------------------------

#ifndef BEAMFUNC_CONV_BASE_HPP
#define BEAMFUNC_CONV_BASE_HPP

#include "beamfunc/InterpolateConv.hpp"

#include <map>

namespace beamfunc
{

//------------------------------------------------------------------------------
class ConvBase
{
   protected:
      // order, convolution name, PDF set, member number and interpolation method
      int _order;
      std::string _pdfset;
      int _imem;
      std::string _method;

      // contains the grid objects for a convolution
      std::map<Convname, InterpolateConv*> _convs;

   public:
      // constructor and destructor
      ConvBase(int order, std::string pdfset, int imem, std::string method);
      ~ConvBase() { _convs.clear(); }

      // return the value for a given convolution at given flavor, x, muB
      double convValue(Convname convname, int pid, double x, double muB);

   private:
      // function to construct the map
      virtual void initConvMap() = 0;
};

//------------------------------------------------------------------------------
inline ConvBase::ConvBase(int order, std::string pdfset, int imem, std::string method)
   : _order(order), _pdfset(pdfset), _imem(imem), _method(method) {}

//------------------------------------------------------------------------------
// Function to perform interpolation and return value at given x and muB
inline double ConvBase::convValue(Convname convname, int pid, double x, double muB)
{
   return _convs[convname]->interpolate(pid, x, muB);
}

} // namespace beamfunc

#endif // BEAMFUNC_CONV_BASE_HPP
