//------------------------------------------------------------------------------
/// \file ConvOptions.hpp
//
// Author(s):
//    Jon Walsh, Frank Tackmann
//
// Copyright:
//    Copyright (C) 2017  DESY
//
//    This file is part of the SCETlib library. SCETlib is distributed under the
//    terms of the GNU General Public License version 3 (GPLv3), see the COPYING
//    file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Definitions of available convolutions and flavors
//------------------------------------------------------------------------------

#ifndef BEAMFUNC_CONV_OPTIONS_HPP
#define BEAMFUNC_CONV_OPTIONS_HPP

namespace beamfunc
{

// ------------------------------------------------------------------------------
// available flavors, including the singlet
// ------------------------------------------------------------------------------
enum Flavor
{
   kDown         = 1,    kDownBar      = -1,
   kUp           = 2,    kUpBar        = -2,
   kStrange      = 3,    kStrangeBar   = -3,
   kCharm        = 4,    kCharmBar     = -4,
   kBottom       = 5,    kBottomBar    = -5,
   kTop          = 6,    kTopBar       = -6,
   kGluon = 21,
   kPhoton = 22,
   kSinglet = 99
};

//------------------------------------------------------------------------------
// Available convolutions
//------------------------------------------------------------------------------
enum Convname
{
   // the ConvName has a free flavor index on the PDF, labeled by 'x'
   // e.g. to get (Pqq x fq) or (Pqg x fg) you would use kPqx_fx with either a gluon or quark (or singlet) flavor
   // PDF
   k_fx,
   // quark QCD convolutions
   // LO
   kPqx_fx,
   // NLO
   kP1qqV_fq,
   kP1qqbarV_fq,
   kP1qqS_fq,
   kP1qg_fg,
   // LO x LO
   kPqqPqx_fx,
   kPqgPgx_fx,

   // quark Tau convolutions
   // NLO
   kIqx_fx,
   // NLO x LO
   kIqqPqx_fx,
   kIqgPgx_fx,
   // NNLO
   kI2qqV_fq,
   kI2qqbarV_fq,
   kI2qqS_fq,
   kI2qg_fg
};

} // namespace beamfunc

#endif // BEAMFUNC_CONV_OPTIONS_HPP
