//------------------------------------------------------------------------------
/// \file InterpolateConv.hpp
//
// Author(s):
//    Jon Walsh, Frank Tackmann
//
// Copyright:
//    Copyright (C) 2017  DESY
//
//    This file is part of the SCETlib library. SCETlib is distributed under the
//    terms of the GNU General Public License version 3 (GPLv3), see the COPYING
//    file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interface of class InterpolateConv
//------------------------------------------------------------------------------

#ifndef BEAMFUNC_INTERPOLATE_CONV_HPP
#define BEAMFUNC_INTERPOLATE_CONV_HPP

#include "beamfunc/ConvOptions.hpp"

#include <string>

namespace LHAPDF
{
class PDF;
}

namespace beamfunc
{

//------------------------------------------------------------------------------
// Create object to perform interpolations and return value
//------------------------------------------------------------------------------
class InterpolateConv
{
   private:
      // convolution name, PDF set, member number and interpolation method
      bool _ispdf;

      // contains the grid object for a convolution
      LHAPDF::PDF* _conv;

   public:
      // constructor and destructor
      InterpolateConv(Convname convname, std::string pdfset, int imem, std::string method);
      ~InterpolateConv();

      double interpolate(int pid, double x, double muB);
};

} // namespace beamfunc

#endif // BEAMFUNC_INTERPOLATE_CONV_HPP
