//------------------------------------------------------------------------------
/// \file QCDQuarkConvs.hpp
//
// Author(s):
//    Jon Walsh, Frank Tackmann
//
// Copyright:
//    Copyright (C) 2017  DESY
//
//    This file is part of the SCETlib library. SCETlib is distributed under the
//    terms of the GNU General Public License version 3 (GPLv3), see the COPYING
//    file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interface of class QCDQuarkConvs
//------------------------------------------------------------------------------

#ifndef BEAMFUNC_QCD_CONVS_HPP
#define BEAMFUNC_QCD_CONVS_HPP

#include "beamfunc/ConvBase.hpp"

namespace beamfunc
{

//------------------------------------------------------------------------------
class QCDQuarkConvs : public ConvBase
{
   public:
      // constructor and destructor
      QCDQuarkConvs(int order, std::string pdfset, int imem, std::string method) : ConvBase(order, pdfset, imem, method) { initConvMap(); }
      virtual ~QCDQuarkConvs() {}

   private:
      // function to construct the map
      virtual void initConvMap();
};

//------------------------------------------------------------------------------
// construct the map of convolutions
inline void QCDQuarkConvs::initConvMap()
{
   // LO
   _convs[k_fx] = new InterpolateConv(k_fx, _pdfset, _imem, _method);
   // NLO
   if (_order >= 1) {
      _convs[kPqx_fx] = new InterpolateConv(kPqx_fx, _pdfset, _imem, _method);
   }
   // NNLO
   if (_order >= 2) {
      _convs[kP1qqV_fq] = new InterpolateConv(kP1qqV_fq, _pdfset, _imem, _method);
      _convs[kP1qqbarV_fq] = new InterpolateConv(kP1qqbarV_fq, _pdfset, _imem, _method);
      _convs[kP1qqS_fq] = new InterpolateConv(kP1qqS_fq, _pdfset, _imem, _method);
      _convs[kP1qg_fg] = new InterpolateConv(kP1qg_fg, _pdfset, _imem, _method);
      _convs[kPqqPqx_fx] = new InterpolateConv(kPqqPqx_fx, _pdfset, _imem, _method);
      _convs[kPqgPgx_fx] = new InterpolateConv(kPqgPgx_fx, _pdfset, _imem, _method);
   }
}

} // namespace beamfunc

#endif // BEAMFUNC_QCD_CONVS_HPP
