//------------------------------------------------------------------------------
/// \file TauCoeffsQuark.hpp
//
// Author(s):
//    Jon Walsh, Frank Tackmann
//
// Copyright:
//    Copyright (C) 2017  DESY
//
//    This file is part of the SCETlib library. SCETlib is distributed under the
//    terms of the GNU General Public License version 3 (GPLv3), see the COPYING
//    file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interface of classes TauCoeffsQuark
//------------------------------------------------------------------------------

#ifndef BEAMFUNC_TAU_COEFFS_QUARK_HPP
#define BEAMFUNC_TAU_COEFFS_QUARK_HPP

#include "beamfunc/QCDQuarkConvs.hpp"
#include "beamfunc/TauQuarkConvs.hpp"

namespace beamfunc
{

//------------------------------------------------------------------------------
/**
 * \class   TauCoeffsQuark
 * \ingroup beamfunc
 *
 * \brief   Quark beamthrust beam function coefficients at fixed order
 *
 * The coefficients are implemented up to NNLO.
 */
//------------------------------------------------------------------------------
class TauCoeffsQuark
{
   private:
      // convolution objects, QCD and TauB
      QCDQuarkConvs* _convsQCD;
      TauQuarkConvs* _convsTau;

      int _nf;

   public:
      // constructor and destructor
      TauCoeffsQuark(int order, std::string pdfset, int imem, int nf);
      ~TauCoeffsQuark();

      // calculate a coefficient for a given point
      double Biqj(int order, int logorder, int pid, double x, double muB);

   private:
      double B0qm1(int pid, double x, double muB); // LO, delta function
      double B1qm1(int pid, double x, double muB); // NLO, delta function
      double B1q0(int pid, double x, double muB); // NLO, L0
      double B1q1(int pid, double x, double muB); // NLO, L1
      double B2qm1(int pid, double x, double muB); // NNLO, delta function
      double B2q0(int pid, double x, double muB); // NNLO, L0
      double B2q1(int pid, double x, double muB); // NNLO, L1
      double B2q2(int pid, double x, double muB); // NNLO, L2
      double B2q3(int pid, double x, double muB); // NNLO, L3
};

} // namespace beamfunc

#endif // BEAMFUNC_TAU_COEFFS_QUARK_HPP
