//------------------------------------------------------------------------------
/// \file TauQuarkConvs.hpp
//
// Author(s):
//    Jon Walsh, Frank Tackmann
//
// Copyright:
//    Copyright (C) 2017  DESY
//
//    This file is part of the SCETlib library. SCETlib is distributed under the
//    terms of the GNU General Public License version 3 (GPLv3), see the COPYING
//    file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Interface of class TauQuarkConvs
//------------------------------------------------------------------------------

#ifndef BEAMFUNC_TAU_QUARK_CONVS_HPP
#define BEAMFUNC_TAU_QUARK_CONVS_HPP

#include "beamfunc/ConvBase.hpp"

namespace beamfunc
{

//------------------------------------------------------------------------------
class TauQuarkConvs : public ConvBase
{
   public:
      TauQuarkConvs(int order, std::string pdfset, int imem, std::string method) : ConvBase(order, pdfset, imem, method) { initConvMap(); }
      virtual ~TauQuarkConvs() {}

   private:
      // function to construct the map
      virtual void initConvMap();
};

//------------------------------------------------------------------------------
// construct the map of convolutions
inline void TauQuarkConvs::initConvMap()
{
   // NLO
   if (_order >= 1) {
      _convs[kIqx_fx] = new InterpolateConv(kIqx_fx, _pdfset, _imem, _method);
   }
   // NNLO
   if (_order >= 2) {
      _convs[kIqqPqx_fx] = new InterpolateConv(kIqqPqx_fx, _pdfset, _imem, _method);
      _convs[kIqgPgx_fx] = new InterpolateConv(kIqgPgx_fx, _pdfset, _imem, _method);
      _convs[kI2qqV_fq] = new InterpolateConv(kI2qqV_fq, _pdfset, _imem, _method);
      _convs[kI2qqbarV_fq] = new InterpolateConv(kI2qqbarV_fq, _pdfset, _imem, _method);
      _convs[kI2qqS_fq] = new InterpolateConv(kI2qqS_fq, _pdfset, _imem, _method);
      _convs[kI2qg_fg] = new InterpolateConv(kI2qg_fg, _pdfset, _imem, _method);
   }
}

} // namespace beamfunc

#endif // BEAMFUNC_TAU_QUARK_CONVS_HPP
