//------------------------------------------------------------------------------
/// \file SingleBin.cpp
//
// Author(s):
//    Simone Alioli, Frank Tackmann
//
// Copyright:
//    Copyright (C) 2017 CERN, DESY
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Implementation of class SingleBin
//------------------------------------------------------------------------------

#include "Geneva/Analyzers/SingleBin.hpp"

#include <iomanip>

namespace Geneva
{

//------------------------------------------------------------------------------
// Manipulation
//------------------------------------------------------------------------------

//------------------------------------------------------------------------------
void SingleBin::initialize()
{
   assert(!_canAddWeight);
   _tmpwt.clear();
   _canAddWeight = true;
}

//------------------------------------------------------------------------------
void SingleBin::fill(const Sigma& weight)
{
   assert(_canAddWeight);
   // only fill if the Sigma is defined
   if (weight.isDefined()) {
      if (!_tmpwt.isDefined()) {
         _tmpwt = weight;
      } else {
         _tmpwt += weight;
      }
   }
}

//------------------------------------------------------------------------------
void SingleBin::finalize()
{
   assert(_canAddWeight);
   _rate.addWeight(_tmpwt);
   _canAddWeight = false;
}

//------------------------------------------------------------------------------
void SingleBin::reset()
{
   _rate.reset();
   _tmpwt.clear();
   _canAddWeight = false;
}

//------------------------------------------------------------------------------
// Private member functions
//------------------------------------------------------------------------------

//------------------------------------------------------------------------------
// Streams a string in the format "name  entries  central value +/- error" to out.
std::ostream& SingleBin::print(std::ostream& out) const
{
   assert(!_canAddWeight);
   out << std::setw(23) << name() << "  ";
   out << rate();
   return out;
}

} // namespace Geneva
