//------------------------------------------------------------------------------
/// \file PhiNLOppVjFKS.cpp
//
// Author(s):
//   Simone Alioli
//
// Copyright:
//    Copyright (C) 2014 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Implementations of PhiNLOppVjFKS classes
//------------------------------------------------------------------------------

#include "Geneva/Calculations/PhiNLOppVjFKS.hpp"

#include "Geneva/Core/Physics/NJettiness.hpp"

namespace Geneva
{

//------------------------------------------------------------------------------
bool PhiNLOppVjFKS::projectionOutsideMapBoundaries(PhiNplus1 phiNp1CM, double xA, double xB) const
{
   Configuration phiN;
   if (!_mapFKS.project(phiNp1CM, phiN))
      return true;

   // For FKS we can have the situation where Tau0(Phi2) > Tau0cut > Tau0(Phi1^FKS(Phi2)).
   // Such events will not be part of the NLO1 bin, since it always has
   // Tau0(Phi1^FKS(Phi2)) > Tau0cut. Here, we treat these otherwise projectable
   // Phi2 points as failing the projection by definition, which puts them into
   // the LO2 bin.
   return ZeroJettinesspp(phiN)() < _tau0Cut;
}

} // namespace Geneva
