//------------------------------------------------------------------------------
/// \file OneLoopMEOpenLoops.cpp
//
// Author(s):
//    Simone Alioli
//
// Copyright:
//    Copyright (C) 2012 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Implementation of class OneLoopMEOpenLoops
//------------------------------------------------------------------------------

#include "Geneva/Components/OneLoopMEOpenLoops.hpp"
#include "Geneva/Components/OpenLoopsInterface.hpp"

namespace Geneva
{

//------------------------------------------------------------------------------
OneLoopMEOpenLoops::OneLoopMEOpenLoops(const OptionMap& optMap)
{
   OpenLoopsInterface::instance().addLoopProcesses(optMap);
}

//------------------------------------------------------------------------------
double OneLoopMEOpenLoops::getDoublePole(const Configuration& config) const
{
   const double alphas = 1.0;
   const double alphaEm = 1.0;
   double lo;
   double res[3];
   double acc;
   OpenLoopsInterface::instance().evaluateLoop(config, _scale, alphas, alphaEm, &lo, res, &acc);
   return res[2];
}

//------------------------------------------------------------------------------
double OneLoopMEOpenLoops::getSinglePole(const Configuration& config) const
{
   const double alphas = 1.0;
   const double alphaEm = 1.0;
   double lo;
   double res[3];
   double acc;
   OpenLoopsInterface::instance().evaluateLoop(config, _scale, alphas, alphaEm, &lo, res, &acc);
   return res[1];
}

//------------------------------------------------------------------------------
double OneLoopMEOpenLoops::getFiniteTerm(const Configuration& config) const
{
   const double alphas = 1.0;
   const double alphaEm = 1.0;
   double lo;
   double res[3];
   double acc;
   OpenLoopsInterface::instance().evaluateLoop(config, _scale, alphas, alphaEm, &lo, res, &acc);
   return res[0];
}

//------------------------------------------------------------------------------
bool OneLoopMEOpenLoops::getAllTerms(const Configuration& config, double& doublePole, double& singlePole, double& finiteTerm) const
{
   const double alphas = 1.0;
   const double alphaEm = 1.0;
   double lo;
   double res[3];
   double acc;
   OpenLoopsInterface::instance().evaluateLoop(config, _scale, alphas, alphaEm, &lo, res, &acc);
   doublePole = res[2];
   singlePole = res[1];
   finiteTerm = res[0];
   return true;
}

//------------------------------------------------------------------------------
std::string OneLoopMEOpenLoops::name() const
{
   return "OpenLoops";
}

} // end namespace Geneva
