//------------------------------------------------------------------------------
/// \file SplittingMappingBase.cpp
//
// Author(s):
//    Christian Bauer, Frank Tackmann
//
// Copyright:
//    Copyright (C) 2016 LBNL, DESY
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Implementation of class SplittingMappingBase
//------------------------------------------------------------------------------

#include "Geneva/Components/SplittingMappingBase.hpp"

#include "Geneva/Core/UI/Log.hpp"

#include <iostream>

#include <gsl/gsl_errno.h>
#include <gsl/gsl_roots.h>

namespace Geneva
{

//------------------------------------------------------------------------------
RegionInfoList SplittingMappingBase::getRegionInfoList()
{
   return _regionsInfo;
}

//------------------------------------------------------------------------------
SignatureSet SplittingMappingBase::sigsN()
{
   return _signaturesN;
}

//------------------------------------------------------------------------------
SignatureSet SplittingMappingBase::sigsNmin1()
{
   return _signaturesNmin1;
}

//------------------------------------------------------------------------------
std::list<RegionInfo> SplittingMappingBase::getAllowedSplittings(const RegionInfo& map)
{
   //This only gives the splittings that are allowed given the PhiN of the map, and which have the same radiation type (which implements the theta functions in the splitting functions)

   //First, find all singular regions that can come from the given Nmin1-body signature
   std::list<RegionInfo>  splittings = _regionsInfo.getSingularRegionsFromSignature(*(map.fN));

   //Now find all singular region where the emitter is equal to the one of the map
   for (std::list<RegionInfo>::iterator it = splittings.begin(); it != splittings.end(); ++it) {
      if (not (it->k == map.k)) { // or not it->i->isGluon()) {
         it = splittings.erase(it);
         --it;
      }
   }
   return splittings;
}

//------------------------------------------------------------------------------
std::list<RegionInfo> SplittingMappingBase::getAllowedProjections(const RegionInfo& map)
{
   //This only gives the splittings that are allowed given the PhiN of the map, and which have the same radiation type (which implements the theta functions in the splitting functions)

   //First, find all singular regions that can come from the given Nmin1-body signature
   std::list<RegionInfo>  splittings = _regionsInfo.getSingularRegionsToSignature(*(map.fNp1));

   return splittings;
}

} // namespace Geneva
