//------------------------------------------------------------------------------
/// \file TreeMECompleteOpenLoops.cpp
//
// Author(s):
//    Simone Alioli
//
// Copyright:
//    Copyright (C) 2012 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Implementation of class TreeMECompleteOpenLoops
//------------------------------------------------------------------------------

#include "Geneva/Components/TreeMECompleteOpenLoops.hpp"
#include "Geneva/Components/OpenLoopsInterface.hpp"

#include "Geneva/Core/Physics/QCDUtils.hpp"

#include <complex>

namespace Geneva
{

//------------------------------------------------------------------------------
TreeMECompleteOpenLoops::TreeMECompleteOpenLoops(const OptionMap& optMap) : _config(0)
{
   OpenLoopsInterface::instance().addTreeProcesses(optMap);
}

//------------------------------------------------------------------------------
// Returns the value of the squared tree-level matrix element for the given configuration.
/**
 * TODO: document me!
 */
void TreeMECompleteOpenLoops::calculate(const Configuration& config)
{
   const double alphas = 1.0;
   const double alphaEm = 1.0;
   const double scale = std::numeric_limits< double >::quiet_NaN();

   _config = &config;
   size_t np = config.size();
   _ccvalue.assign((np*(np-1))/2, 0);
   _scvalue.assign(np*16, 0);
   double resEWcc = std::numeric_limits< double >::quiet_NaN();
   OpenLoopsInterface::instance().evaluateTreeComplete(config, scale, alphas, alphaEm, &_value, _ccvalue.data(), _scvalue.data(), &resEWcc);

}

static inline size_t nis(size_t i, size_t j)
{
   return i <= j ? i + j * (j - 1) / 2 : j + i * (i - 1) / 2;
}

//------------------------------------------------------------------------------
double TreeMECompleteOpenLoops::colorMatrix(Configuration::const_iterator it_i, Configuration::const_iterator it_j) const
{
   if (IsQCDPair()(it_i->id(), it_j->id()) && it_i != it_j) {
      const size_t i = static_cast<size_t>(std::distance(_config->begin(), it_i));
      const size_t j = static_cast<size_t>(std::distance(_config->begin(), it_j));
      return -_ccvalue[nis(i, j)];
   }
   return 0.;
}

//------------------------------------------------------------------------------
double TreeMECompleteOpenLoops::polarizationMatrix(Configuration::const_iterator it_i, size_t mu, size_t nu) const
{
   // this should only be called on gluons
   assert(it_i->id().isGluon());
   const size_t i = static_cast<size_t>(std::distance(_config->begin(), it_i));
   return _scvalue[i * 16 + mu * 4 + nu];
}

//------------------------------------------------------------------------------
const std::string TreeMECompleteOpenLoops::name() const
{
   return "TreeMECompleteOpenLoops ";
}

} // end namespace Geneva
