//------------------------------------------------------------------------------
/// \file TreeMEOpenLoops.cpp
//
// Author(s):
//    Simone Alioli
//
// Copyright:
//    Copyright (C) 2012 LBNL
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Implementation of class TreeMEOpenLoops
//------------------------------------------------------------------------------

#include "Geneva/Components/TreeMEOpenLoops.hpp"
#include "Geneva/Components/OpenLoopsInterface.hpp"

namespace Geneva
{

//------------------------------------------------------------------------------
TreeMEOpenLoops::TreeMEOpenLoops(const OptionMap& optMap)
{
   OpenLoopsInterface::instance().addTreeProcesses(optMap);
   _colorFlowBasis = OpenLoopsInterface::instance().getColorFlowBasis();
}

//------------------------------------------------------------------------------
/**
 * TODO: document me!
 */
void TreeMEOpenLoops::calculateValue(const Configuration& config)
{
   _config = &config;
   const double alphas = 1.0;
   const double alphaEm = 1.0;
   // pass in a NaN, to make sure nothing depends on this
   const double scale = std::numeric_limits< double >::quiet_NaN();
   OpenLoopsInterface::instance().evaluateTree(config, scale, alphas, alphaEm, &_value);
}

//------------------------------------------------------------------------------
/**
 * TODO: document me!
 */
void TreeMEOpenLoops::calculateColorInfo(const Configuration& config)
{
   // NOTE: The current ITreeMEColor interface forces us to keep a pointer to the config.
   _config = &config;
   const double alphas = 1.0;
   const double alphaEm = 1.0;
   // pass in a NaN, to make sure nothing depends on this
   const double scale = std::numeric_limits< double >::quiet_NaN();
   _valueLargeNc.resize(numColorFlows());
   OpenLoopsInterface::instance().evaluateTreeLargeNc(config, scale, alphas, alphaEm, _valueLargeNc.data());
}

//------------------------------------------------------------------------------
std::pair<int, int> TreeMEOpenLoops::colorIndices(Configuration::const_iterator it_i, colorFlowIndex cf) const
{
   assert(_config->includes(it_i));
   return  _colorFlowBasis.at(Signature(*_config))[cf][size_t_from_ptrdiff_t(std::distance(_config->begin(), it_i))];
}

//------------------------------------------------------------------------------
const std::string TreeMEOpenLoops::name() const
{
   return "TreeMEOpenLoops";
}

} // end namespace Geneva
