//------------------------------------------------------------------------------
/// \file Particle.cpp
//
// Author(s):
//    Erik Strand, Frank Tackmann
//
// Copyright:
//    Copyright (C) 2012 LBNL, MIT
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Implementation of class Particle
//------------------------------------------------------------------------------

#include "Geneva/Core/Physics/Particle.hpp"

#include "Geneva/Core/UI/Log.hpp"

#include <ostream>

namespace Geneva
{

// NOTE: Currently using a trivial hard-coded implementation.
// Later the mass and charge will be retrieved from _data
double _particleMasses[26] = {0.0,
   0.0, 0.0, 0.0, 0.0, 0.0, 173.1, 0.0, 0.0, 0.0, 0.0, // quarks
   0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,   // leptons
   0.0, 0.0, 91.1876, 80.398, 125.0                    // bosons
};

double _particleCharges[26] = {0.,
   -1./3., 2./3., -1./3., 2./3., -1./3., 2./3., -1./3., 2./3., 0., 0., // quarks
   1., 0.0, 1., 0.0, 1.0, 0.0, 1.0, 0.0, 0.0, 0.0,                     // leptons
   0.0, 0.0, 0.0, +1., 0.0                                             // bosons
};

//------------------------------------------------------------------------------
// Queries and Accessors
//------------------------------------------------------------------------------
// Returns the particle's mass.
double Particle::mass() const
{
   if (abs(_id.code()) > 25)
      Log::fatal("Particle::mass") << "Particle masses are currently hard-coded and only available for PDG ids <= 25." << Log::end;
   return _particleMasses[abs(_id.code())];
}

//------------------------------------------------------------------------------
// Returns the particle's charge.
double Particle::charge() const
{
   if (abs(_id.code()) > 25)
      Log::fatal("Particle::charge") << "Particle charges are currently hard-coded and only available for PDG ids <= 25." << Log::end;
   return _id.code() > 0 ? _particleCharges[_id.code()] : - _particleCharges[-_id.code()];
}


//------------------------------------------------------------------------------
// Private member functions
//------------------------------------------------------------------------------

// Streams a string in the format "{[id], p0, p1, p2, p3, (color1, color2)}" to out.
std::ostream& Particle::print(std::ostream& out) const
{
   return out << "{[" << _id << "], "
          << _p.p0() << ", " << _p.p1() << ", " << _p.p2() << ", "
          << _p.p3() <<  ", (" << color1() << ", " << color2() << ")}";
}

} // namespace Geneva
