//------------------------------------------------------------------------------
/// \file Exception.cpp
//
// Author(s):
//    Frank Tackmann
//
// Copyright:
//    Copyright (C) 2014 Frank Tackmann
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Implementation of mainExceptionHandler
//------------------------------------------------------------------------------

#include "Geneva/Core/UI/Exception.hpp"
#include "Geneva/Core/UI/Log.hpp"

#include <iostream>
#include <cstdlib>

namespace Geneva
{

//------------------------------------------------------------------------------
int mainExceptionHandler()
{
   try {
      throw;
   } catch (const NoError&) {
      if (Log::info().outStream() << std::endl)
         Log::info().outStream() << "Exiting gracefully ..." << std::endl;
      else
         std::cerr << "(stderr) Exiting gracefully ...";
      return EXIT_SUCCESS;
   } catch (const AnyError& err) {
      if (!err.isLogged())
         std::cerr << "(stderr) Unlogged " << err.name()
                   << " from " << err.where()
                   << ": " << err.what() << std::endl;
   } catch (const std::exception& e) {
      if (Log::error().outStream() << std::endl) {
         Log::error().outStream() << Log::error().color() << "Unhandled exception: ";
         Log::error().color().reset(Log::error().outStream());
         Log::error().outStream() << e.what() << std::endl;
      } else
         std::cerr << "(stderr) Unhandled exception: " << e.what() << std::endl;
      throw;
   } catch (const char* msg) {
      if (Log::error().outStream() << std::endl) {
         Log::error().outStream() << Log::error().color() << "Unhandled exception: ";
         Log::error().color().reset(Log::error().outStream());
         Log::error().outStream() << msg << std::endl;
      } else
         std::cerr << "(stderr) Unhandled exception: " << msg << std::endl;
      throw;
   } catch (...) {
      throw;
   }
   return EXIT_FAILURE;
}

} // namespace Geneva
