//------------------------------------------------------------------------------
/// \file CaptureOutput.cpp
//
// Author(s):
//    Simone Alioli
//
// Copyright:
//    Copyright (C) 2017 UNIMIB
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Implementation of class CaptureOutput
//------------------------------------------------------------------------------

#include "Geneva/Core/UI/Log.hpp"
#include "Geneva/Core/Utils/CaptureOutput.hpp"

#include <iostream>

namespace Geneva
{

//------------------------------------------------------------------------------
CaptureOutput::CaptureOutput()
{
   // save std::cout original streambuf
   _coutBuf = std::cout.rdbuf();

   // direct Geneva output into temporary buffer
   Log::setDefaultOutStream(_captured);

   // direct output from external libraries on std::cout into temporary buffer
   std::cout.rdbuf(_captured.rdbuf());
}

//------------------------------------------------------------------------------
CaptureOutput::~CaptureOutput()
{
   if (_logFile.is_open()) {
      _logFile.close();
   }
   // restore default std::cout
   std::cout.rdbuf(_coutBuf);

   // redirect all remaining captured content that has not already been redirected
   std::cout << _captured.str();

   // restore Geneva default stream to std::cout
   Log::setDefaultOutStream(std::cout);
}

//------------------------------------------------------------------------------
void CaptureOutput::direct_to(const std::string& logFileName, bool append)
{
   if (!logFileName.empty()) {
      if (_logFile.is_open()) {
         _logFile.close();
      }
      if (append) {
         _logFile.open(logFileName.c_str(), std::ofstream::app);
      } else {
         _logFile.open(logFileName.c_str());
      }
      if (!_logFile.is_open()) {
         Log::fatal("CaptureOutput") << "Cannot open the log file: " << logFileName << Log::end;
      }

      // redirect output captured until now to log file
      _logFile << _captured.str();

      // clear the temporary capture stream
      _captured.clear();
      _captured.str(std::string());

      // direct all future output to log file
      Log::setDefaultOutStream(_logFile);
      std::cout.rdbuf(_logFile.rdbuf());

   } else {
      if (!append) {
         Log::fatal("CaptureOutput") << "Writing to std::cout only allowed in append mode." << Log::end;
      }
      // restore default std::cout
      std::cout.rdbuf(_coutBuf);

      // redirect output captured until now to std::cout
      std::cout << _captured.str();

      // clear the temporary capture stream
      _captured.clear();
      _captured.str(std::string());

      // direct all future output to std::cout
      Log::setDefaultOutStream(std::cout);
   }
}

} // namespace Geneva
