//------------------------------------------------------------------------------
/// \file CatchSignal.cpp
//
// Author(s):
//    Simone Alioli
//
// Copyright:
//    Copyright (C) 2017 UNIMIB
//
//    This file is part of the Geneva MC framework. Geneva is distributed under
//    the terms of the GNU General Public License version 3 (GPLv3), see the
//    COPYING file that comes with this distribution for details.
//    Please respect the academic usage guidelines in the GUIDELINES file.
//
// Description:
//    Implementation of class CatchSignal
//------------------------------------------------------------------------------

#include "Geneva/Core/Utils/CatchSignal.hpp"
#include "Geneva/Core/UI/Log.hpp"

#include <cstdlib>
#include <iostream>

namespace Geneva
{

//------------------------------------------------------------------------------
CatchSignal::CatchSignal(int signal)
{
   if (signal == SIGINT) {
      // Install a signal handler to capture SIGINT (CTRL+C).
      struct sigaction new_handler;
      new_handler.sa_handler = _handler;
      sigemptyset(&new_handler.sa_mask);
      new_handler.sa_flags = 0;
      sigaction(SIGINT, &new_handler, &_old_handler);
   } else {
      Log::fatal("CatchSignal") << "Catching signal " << signal << " is not yet supported." << Log::end;
   }
}

//------------------------------------------------------------------------------
CatchSignal::~CatchSignal()
{
   sigaction(SIGINT, &_old_handler, 0);
}

//------------------------------------------------------------------------------
void CatchSignal::_handler(int signal)
{
   if (signal == SIGINT) {
      std::cerr << "\n(stderr) Caught interrupt signal, exiting ...\n";
      std::exit(EXIT_FAILURE);
   }
}

} // namespace Geneva
